Washington (CNN) -- Four decades since Roe v. Wade, and little, it seems, has changed.

The January 22, 1973, Supreme Court decision legalizing abortion remains the law of the land, passions remain high on both sides of the issue, and protests are held each year on its anniversary.

Access to abortion, then and now, is about more than simple legalities. Social, religious and family values, as well as finances and politics, still play a role in shaping the abortion issue, but many legal and medical experts say the debate has become entrenched.
"Much of the controversy about abortion is really stimulated by the interest groups on both sides of the political question, rather than by ordinary Americans," said David Garrow, a law professor at the University of Pittsburgh, and a longtime Supreme Court scholar. "The American people and many political leaders have already made up their minds about legal abortion."

Public opinion on abortion has remained stable over the years. A CNN/Opinion Research survey last August found 44% said abortion should be legal in all or most circumstances, while 52% said only under few or no circumstances. And 88% said the procedure should be allowed when the woman's life is in danger; 83-percent said so in cases of rape or incest. The margin of error was plus-or-minus 3 points.

The Roe decision did not prompt "abortion on demand," as many opponents of the procedure had predicted it would. Nor have various legislatures or court rulings restricted access as much as some supporters claim.

Research from the Alan Guttmacher Institute finds the number of abortions at its lowest level since Roe, remaining steady at about 1.2 million reported procedures in the year 2011, down 25-percent since the all-time high in 1990.

Bans on abortion in the United States began early in the 19th century. Connecticut in 1812 became first state to outlaw them, specifically after "quickening," the time in the pregnancy when the woman starts to feel fetal movements.

The laws were designed primarily to protect women from dangerous "back alley" abortions. These laws were also ambiguous, given the Victorian moral code that stifled debate on so personal a subject as unwanted pregnancies. Since then, movements have come and gone to relax the restrictions or to give women more choice, but such efforts mostly went nowhere.

It was not until the 1960s that an organized movement was launched to ease the laws regulating abortions. Medical technology had advanced to the point where they could be done safely by trained medical staff in clean, professional environments. By the early 1970s, a number of states had changed their laws, though most did so in very limited ways.

Survey: Few religious groups want decision overturned despite abortion views

The legal fights culminated with Roe v. Wade, the court's 7-2 decision giving women a qualified constitutional right to abortion during most of the pregnancy. The court, in fact, heard two cases around the same time: Roe (aka Norma McCorvey, who has since become an abortion opponent), which challenged a Texas law banning abortions except to save the woman's life; and Doe v. Bolton, involving a Georgia law requiring that abortions be performed only in accredited hospitals and only after a review by a hospital staff committee and an exam by two doctors other than the woman's physician.

The Roe and Doe rulings affected laws in 46 states.

For the justices, Roe reflected earlier cases involving the right to privacy. That "right," wrote Justice Harry Blackmun in the main opinion for the court, is "broad enough to encompass a woman's decision whether or not to terminate her pregnancy."

"Prior to Roe," said Garrow, "whether one could obtain a legal abortion in the face of an unwanted pregnancy was a crapshoot. For 40 years now, it's been a constitutionally guaranteed right."

He is the 1994 author of "Liberty and Sexuality: The Right to Privacy and the Making of Roe v. Wade."

But the ruling was a qualified one, and that fact has been used by abortion opponents in their efforts to narrow the scope of other abortion provisions. Blackmun noted that the state's "important interests in safeguarding health, maintaining medical standards, and protecting potential life" are compelling enough to justify regulation "at some point in pregnancy."

That "qualified right" found its form in the controversial "trimester analysis" laid out by the justices in Roe: permitting no government regulation during the first three months of a pregnancy; allowing limited regulation in the second trimester to protect the woman's health and safety; and granting government the power to ban abortions during the third trimester -- a time when, medical consensus has concluded, the fetus is capable of living on its own.

That reasoning has outraged abortion opponents and puzzled many legal scholars.

"The better argument for the result reached in Roe v. Wade," said Edward Lazarus -- a former law clerk for Blackmun and an author of "Closed Chambers: The Rise, Fall, and Future of the Modern Supreme Court"-- "is that it's necessary for the equality of women, rather than grounding it in the privacy right."

After Roe, the high court affirmed the right to abortion in subsequent cases: striking down provisions requiring a husband's consent for a first-trimester abortion; requiring parental consent for an unmarried woman under 18; striking down efforts to expand on laws requiring women to give informed consent before having an abortion; striking down a 24-hour waiting period; and striking down a law requiring doctors to inform women of the risks and of assistance available if she were to carry the fetus to term.

But there was one notable victory for abortion opponents: a ban on the use of taxpayer funds to finance abortions for poor women.

The abortion issue has been revisited several times since Roe, most famously in Webster v. Reproductive Health Services (1989) and Planned Parenthood v. Casey (1992).

Opinion: If Ireland had Roe v. Wade

Webster (a 5-4 decision) upheld major parts of a Missouri abortion law that prohibited the use of public facilities or the participation of public employees in abortions, and required doctors to test the viability of the fetus before an performing any abortion.

Justices William Rehnquist, Byron White and Anthony Kennedy said they would allow restrictions on abortion, but only if the restrictions had a rational basis. More important, the three conservative justices said, a compelling government interest need not be required to justify restrictions on abortion. That was a blow for anti-abortion forces.

Then came the Casey ruling, in which the justices outlined their views on Roe. The decision (also 5-4) reaffirmed the heart of Roe while giving states the power to regulate procedures so long as they did not impose an "undue burden" on a woman's right to abortion. The standard: Undue burden exists if "the purpose and effect is to place substantial obstacles in the path of a woman seeking an abortion before the fetus attains viability." The ruling left supporters on both sides of the issue dissatisfied, feeling it was ambiguous.

Justice Sandra Day O'Connor joined neither opinion, saying there was nothing in it to justify reconsidering Roe. Nevertheless, Blackmun wrote, "the right to reproductive choice" was in danger of being overturned.

Another legacy of Roe: The head-counting of justices on the court, a what-if scenario that could lead to the overturning of Roe. The current 5-4 conservative majority might shift in either direction if two or more justices leave the bench in the next few years, as is widely expected.

In the meantime, conservatives in Congress have promised to push for tougher restrictions on access to abortion, though many political experts say the goal is not necessarily aimed at overturning Roe.

They found success five years ago when the justices, in a 5-4 ruling, upheld a federal ban on a controversial late-term procedure, rejecting concerns the law didn't take into account the physical safety of the woman.

The procedure -- called "partial birth abortion" by its critics -- is typically performed in the middle-to-late second trimester. The legal sticking point was that the law lacked a "health exception" for women who might suffer serious medical complications, something the justices have said in the past is necessary when considering abortion restrictions.

The swing vote, as in previous cases, came from Kennedy. In angry dissent, Justice Ruth Bader Ginsburg, then the lone woman on the high court, called the majority's conclusions "alarming" and said they "cannot be understood as anything other than an effort to chip away a right declared again and again by this court, and with increasing comprehension of its centrality to women's lives."

Ginsburg has long been a leading voice for gender equality. Ironically, some of the opposition to her 1993 nomination to the high court came from feminists, who did not like her criticism over the legal reasoning of Roe.

She believed a more gradual liberalization to abortion would have kept the issue back in the states, avoiding the social and political upheaval that has been part of Roe's legacy. The law on abortion was evolving at the time of Roe, Ginsburg recalled in 2005. "The Supreme Court stopped all that by deeming every law -- even the most liberal -- as unconstitutional. That seemed to me not the way courts generally work."

But Ginsburg, in her rulings, has upheld a woman's reproductive choice. "When government controls that decision for her, she's being treated as less than a full adult human being responsible for her own choices," she said during her confirmation.

If there is one overriding legacy of the Roe decision, it may be that it opened and expanded the debate on the rights of women, sexuality, health care, and medical decisions. Issues like cloning, stem cells, and fetal research have become part of the national lexicon. As significant as it was, Roe v. Wade was only the beginning of the battle.

@highlight

40 years later, Roe remains the law of the land

@highlight

Passions still run high on both sides of the landmark decision

@highlight

In 1812, Connecticut outlawed abortions after "quickening"