Washington (CNN) -- The U.S. Supreme Court is prepared to take on an emotionally charged case: the massive health care reform legislation championed by President Barack Obama.

The court will hear six hours of oral arguments over three days on the law's constitutionality. Here are some frequently asked questions on the crucial issues:

Question: What is the law and who is challenging it?

Answer: The Patient Protection and Affordable Care Act (PPACA) was passed by Congress in 2010 by a Democratic congressional majority with the support of the president. It has about 2,700 pages and contains 450 some provisions. The signature policy accomplishment thus far of Obama's presidency, the comprehensive legislation has received mixed reviews in the lower federal courts.

Preview: 'The implications ... are impossible to overstate'

One part of the law stands as the focus of the judicial dispute and threatens to collapse the entire legislation. The "individual mandate" provision requires most Americans to purchase health insurance by 2014 or face a financial penalty. Its purpose is to spread health care costs to a larger pool of individuals.

Various states and individuals have argued the Constitution's Commerce Clause does not give government the authority to force Americans to purchase a commercial product such as health insurance they may not want or need. The opposing states equate such a requirement to a burdensome regulation of "inactivity."

The Justice Department has countered by saying the changes do not amount to taxpayer financing or a new government-run program. Supporters say Congress wanted to ensure universal coverage by forcing insurance companies to expand coverage without bankrupting them. The individual mandate, they argue, will ensure enough money is in the system to benefit all Americans. Federal officials cite 2008 figures of $43 billion in uncompensated costs from the millions of uninsured people who receive health services, costs that are shifted to insurance companies and passed on to consumers.

The largest and broadest legal challenge to the PPACA comes from a joint filing by 26 states, led by Florida. It was that series of appeals the high court has accepted for review. Lawyers for the states and a private business coalition will argue their case against the Justice Department, representing the administration and Congress.

An insider's look at how the Supreme Court works

Question: What specific issues will the court address?

Answer: The court will decide four separate legal questions in these appeals:

-- Key issue: Does the law overstep federal authority? This is particularly in regard to the key coverage and funding provision: an "individual mandate" requiring most Americans to purchase health insurance or pay a financial penalty.

-- Domino-effect issue: Must the entire PPACA be scrapped if that key provision is unconstitutional?

-- National policy implications issue: Are states being "coerced" by the federal government to expand their share of Medicaid costs and administration, with the risk of losing that funding if they refuse?

-- Jurisdictional issue: Are the lawsuits brought by the states and other petitioners barred under the Anti-Injunction Act, and must they wait until the law goes into effect?

This simplifies the legal issues to some extent, given the sweep and complexity of the healthcare law. The high court's focus will be more about how to pay for the medical care, and less about the new or expanded services the law would guarantee.

Question: I won't be among the lucky few who can get seats to these historic arguments. What will go inside the courtroom?

Answer: The court has carved out its entire week of arguments for this issue -- six hours spread over three days -- in an extremely rare move.

Ceremony and decorum will reign. Court sessions begin promptly at 10 a.m. ET, with the marshal calling the court to order. The chief justice, contrary to popular belief, does not use the wooden gavel. The audience rises as the robed justices enter through red velvet curtains from a back room. After a scripted welcome read by the marshal -- "oyez, oyez, oyez..." -- the sessions begin. Chief Justice John Roberts will announce the case and arguments will proceed.

The four appeals here will each last from one to two hours, and each side's lawyers will get equal time. The public is invited but seating is limited to about 400. Many spectators wanting to view history will camp out in line many hours before, on the court's marbled outdoor plaza, waiting for a precious seat.

Question: I know they're called arguments but is that what the justices will be doing -- fighting among themselves?

Answer: "Argument" is misleading but does reflect the adversarial legal system unique in many ways to the United States. Essentially the lawyers separately presenting their cases will be peppered with questions from the justices, often rapid-fire and legally dense. No witnesses, testimony or visual presentations are allowed.

A good appellate lawyer standing at the lectern will be able to think on her feet, answering the questions without giving away too much. Many veteran attorneys will say it is hard to sway a justice at argument to your side, but it's easy to cede your core position with a weak presentation. Confidence but not arrogance is the tricky balance a lawyer must navigate, as is the ability to anticipate where the line of questioning may lead.

A case does not reach the high court because it is easy, and that is true with this complex health care law.

The justices inevitably tread on the rim of the nation's laws -- the "outer markers" as Justice Stephen Breyer put it -- and must craft a constitutionally credible ruling that will establish precedent, addressing guidelines for courts perhaps many decades.

To help them, the justices offer hypotheticals in their questions, seeing how far the Constitution or issue at hand can be taken and still satisfy judicial scrutiny. The more outrageous the hypothetical, the easier it sometimes is for a wavering justice to get her head around a troubling aspect.

Tensions do get high in the court sometimes, as the justices not only compete for time to ask questions but spar over ideology and legal reasoning. The chief justice is the gatekeeper of sorts, keeping the debate civil and ensuring one justice does not step on another and that a lawyer has time to answer the question. Seniority gives way when two justices talk at the same time.

Reporters and court watchers will look for clues in the justices' comments and questions about how they will eventually vote. A withering line of questions from justices on both the left and right aimed at one lawyer does not necessarily spell doom for a particular side, but it may give the bench more to think about than they had anticipated.

Some justices, such as Antonin Scalia, will bluntly tell his colleagues at argument what he thinks of the case, while others, such as Sonia Sotomayor, are more opaque, equally tough in questioning both sides. Justice Clarence Thomas has not spoken at argument in more than six years, preferring to let the lawyers plead their case without much interruption. That scenario will not happen on this "hot" verbally active bench.

Question: So what happens afterward?

Answer: One thing is certain: We will not get a ruling from bench at argument or shortly thereafter. The justices will meet privately as a group, perhaps Thursday or Friday, where they will go ahead and vote on the four issues.

The chief justice will lead the debate, going by seniority down the line. Each justice will say how he or she votes and can offer a brief explanation of the reasoning, brief being the key word. The current bench does not favor long-winded discussions at their closed-door conference, the substance of which is never revealed publicly.

The court speaks through, and draws it power from, their written opinions. Thus the opinion-crafting process is all-important. The chief justice -- when he is in the majority-- has the power to assign the author of the main ruling. Remember, there are four issues here, and we will likely get four separate written decisions. Because the questions are related, it will make the writing and collaboration process that much more difficult, so it is likely we will not get opinions until late June. Five votes are needed for a majority. The losing side by tradition drafts a written dissent.

The real work of the court goes on behind the scenes as the justices communicate with their respective chambers to craft majority and dissenting opinions that each side can sign onto in support. An individual justice has the power to write a separate "concurrence," supporting the outcome, but for different legal reasons. The more concurrences that pop up, the less force that majority opinion commands, since future courts will see mixed messages over the legal interpretation.

Divided 5-4 rulings also diminish the force of jurisprudence, since the public may view the issue as a strictly partisan exercise along ideological lines. The court has five justices that can reliably be called "conservative," and four justices that can reliably be called "liberal" -- terms the justices themselves dispute and refute. But in these health care cases, the breakdown of the rulings may not fall along expected divisions. That unpredictability makes the current Roberts court so fascinating to watch.

Finally, the court will not announce beforehand exactly when it hands down the rulings, but the justices are set to end their work for the summer in late June. So between now and then, reporters and interested parties will dutifully show up on scheduled "opinion days" and wait for history -- and the discretion of nine independent justices -- to reveal itself.

@highlight

What specific questions will the Supreme Court address?

@highlight

What exactly goes on in the court during a hearing?

@highlight

During "arguments," are the justices really arguing?

@highlight

When can we expect some decisions from the high court?