LONDON, England (CNN) -- It wasn't so long ago that biofuels were being heralded as the savior of the planet and a thoroughly green solution to our climate woes. But fair winds have been replaced by persistent storms of criticism. But is it justified? Principal Voices has spoken to three people -- an economist, a scientist and an environmental campaigner -- at the heart of the biofuels debate. Here, they have their say on biofuels. Have yours at bottom of the page.

The British countryside is transformed in the spring by swathes of rapeseed.

The Economist

Keith Wiebe is the service chief in the Economic and Social Development Department at the Food and Agriculture Organization of the United Nations (FAO). He is currently working on the FAO Annual Report into the state of food and agriculture which this year is focusing on biofuels. The report will be published in September 2008.

Biofuels are obviously playing a role in the current food situation. It is a new source of demand that has risen dramatically over the past couple of years. This has been a significant factor in the increase in commodities prices recently.

What's unique about the past year or two and particularly the past few months is the convergence of a whole number of factors on both the supply side and the demand side.

The background is that you've had the gradually increasing income and demand for more, and different types of food in emerging economies. You've had a gradual decline in international stocks of food, you've got higher oil prices which means the costs of production are going up. There have been some been some production setbacks in a couple of key export countries such as Australia and also a rapid increase in demand for maize and vegetable oils for biodiesel and ethanol production.

All these factors interact and lead to policy responses from countries to limit exports of commodities to protect their domestic consumers. It's impossible to disentangle a specific portion or to attribute a particular portion to the price increases.

One thing to keep in mind is that biofuels play a role in the current high prices but they are certainly not the only factor. The other thing is that they have adverse short term impact on food prices. They have an adverse impact on poor consumers particularly in developing countries. But there is an opportunity over the longer term at least for small farmers who do have access to resources to adjust their production patterns. And high prices give them an incentive to do exactly that.

Small farmers in developing countries see these price incentives and they see they would like to respond. But through a combination of export bans in some countries and poor infrastructure, they are limited in their ability to respond.

I think it is important to distinguish between different types of biofuels. They have very different characteristics. Brazilian sugar cane is the classic example of a type of biofuel that is now performing efficiently and competitively. They are alone among all the major biofuel foodstocks in being competitive at market prices. Whereas in the U.S., maize continues to cost more to produce it than it does to be competitive with the fossil fuel counterpart.

There is a lot of potential in second generation cellulosic technologies but they are not yet commercially viable but that point is coming closer every day. There is so much effort which has gone into this recently and if there is a silver lining to the whole situation it is that people are looking everywhere for alternatives.

Two years ago the general perspective on biofuels was that they were a very bright prospect and to say anything negative about them was somehow a suspect analysis. This situation has been completely reversed.

What we would like to continue to emphasize is that there are many different types of biofuels, some are more promising than others.

Certainly there are things that need to be reevaluated and looked at very carefully. There is also the potential if policies can be improved and investment can be made in agriculture. Many of the world's poor depend on agriculture for their livelihood. We don't want to throw out an opportunity for them.

The Scientist

Dr Richard Pike is the chief executive of the Royal Society of Chemistry. Prior to taking up the role in 2006 he spent 20 years working in the oil industry. He recently calculated that a one-way transatlantic flight would require one year's biofuels yield from an area the size of 30 football pitches.

Biofuels will clearly have an application at a local level. I think there is a general view that at a very local level -- and I'm talking of small townships that are surrounded by land that could cultivate biofuels -- that it is probably sustainable.

Whether it can be applied on a large scale in a sustainable way will vary tremendously from country to country. But one has to be very careful about projecting into the future.

For instance in the UK there is a lot of talk about biofuels, but one of the big issues is the very low efficiency in converting sunlight into the oil or ethanol that you would use to fill up your tank. Typically the efficiency is considerably less than half a percent. That raises the whole issue of land use. If, on the one hand, you've got biofuels which represent only a half a percent conversion of sunlight, and let's say you've got photovoltaic cells and concentrated solar power systems, the efficiency of solar in terms of pure conversion is 50-100 times greater.

In the UK, for every one percent of diesel and petrol you want to replace with biofuel you need, in big round numbers, about one percent of the land area of the UK. That's a very stunning statistic. And it means that if you're looking at notions of self-sufficiency then it's completely out of the window.

If the UK wanted to be more biofuel orientated it would have to import it. Currently the European Union directive is to have 5.75 percent biofuels by 2010. If the UK was to provide that for itself, five percent of the land would have to be utilized -- which is an extraordinary number.

Typically biofuel yields are of the order of three to four tons per hectare. That excludes things like the carbon footprint of fertilizers, harvesting and distribution. The figures you see in the press tend to be focused on the yield from the ground rather than thinking of the bigger picture.

There is a real need to look at the big picture and there's a risk that the focus on biofuels and the idea that it could offer quite a significant contribution is distracting from some of the more important things that need to be looked at. There are lots of small initiatives, either at the user end -- e.g. turning off stand-by switches, drinking tap water -- or the supply end -- e.g. wind energy, tidal energy.

What people are forgetting is that if you look at the energy balance of the world, 80 percent of the world's energy is supplied by fossil fuels. That is likely to remain unchanged for a long time. Fossil fuels are not going to run out that quickly. Reserves figures that you see quoted are very conservative.

The other thing about biofuels is what I call the problem of unintended consequences. Biofuels are clearly going down a route that is bringing it into conflict with food crops and biodiversity. People have talked about a much more efficient biofuel process involving algae. Algae would have significantly high yields. But then again, I don't think enough people have gone through what might happen if that were pursued. You have to ask how it would affect marine life.

The Environmental Campaigner

Deepak Rughani is co-director of Biofuelwatch, a campaign group backing the expanding call for a moratorium on agrofuels* in the European Union.

Biofuelwatch is currently engaged in a new challenge; to help prevent the first biofuel-fired power station to be built in the UK. If energy company Blue-ng is successful a precedent will have been set and according to UK newspaper, The Independent another 43 power stations could follow.

On June 4th, Newham Councilors in east London will meet to make their recommendation on the proposed plant. Coincidently the meeting marks the second day of the UN's High-Level Conference on World Food Security, Climate Change and Bioenergy in Rome. More than 770 organizations and prominent individuals worldwide have signed a Civil Society statement on the World Food Emergency which calls for a halt to all development of land for agrofuels for cars, planes and for energy production in power stations.

So far, only Germany has invested heavily in vegetable oil CHP plants -- 1,800 of them. The vast majority burn palm oil because European vegetable oil is too expensive.

According to experts, the impact on the climate has been disastrous. Peat expert Professor Siegert of Munich University has warned: "We were able to prove that the making of these plantations and the burning of the rainforests and peat areas emits many thousands of times as much CO2 as we then are able to prevent by using palm oil. And that is a disastrous balance for the climate."

Unfortunately, switching to rapeseed oil, even if it was affordable, would not necessarily help matters: As confirmed by a UN report, Europe's use of rapeseed oil for bioenergy is one of the main reasons for rising palm oil prices linked to shortages in the food and cosmetics markets. Inevitably rising prices make deforestation and peat drainage in South East Asia much more profitable.

There are other serious concerns about the east London proposal: Vegetable oil burning leads to emissions of NOx and particulates -- PM 10 and PM 2.5 -- known to have an adverse effect on the respiratory and cardiovascular system. Areas close to the proposed site are currently being monitored as Air Quality Management areas and many residents are very concerned about the plans.

It seems that in the name of decentralized energy generation -- which is likely to be much more efficient than centralized energy generation -- government and companies are willing to both disregard the welfare of local people and at the very time when we need to be dramatically reducing our demand for vegetable oil, offer a new market for agrofuels.

By backing false-solutions we stall investment from the true renewable energies such as wind, solar, wave and geothermal and ignore our responsibility to prevent crossing key climate tipping points, beyond which our current civilization and even much of life on earth could not sustain itself.

* Agrofuels are biofuels produced from crops or trees grown in large-scale monocultures, or agricultural and forest 'waste' which should be returned to the natural system.

@highlight

Once hailed as a climate savior, biofuels are now the subject of widespread criticism

@highlight

FAO economist argues that it is important to distinguish between different biofuels

@highlight

British chemist believes that biofuels can work, but only on at a very local level