Robert King still remembers well the dimensions of his cell: 6 x 9 x 12 feet. There was a steel bed and a sink that doubled as a toilet where he would also wash clothes.

King spent 29 years in solitary confinement in Louisiana. He has been free since 2001, but still has difficulty with geographical orientation.

"I get confused as to where I am, where I should be," he said.

King joined researchers and legal experts at the American Association for the Advancement of Science annual meeting in Chicago this month to talk about the mental and physical health consequences of solitary confinement.

"The widespread consensus among mental health professionals is that solitary confinement, for the overall majority of mentally ill prisoners, places them at severe risk of additional harm," said Craig Haney, director of the program in legal studies at the University of California, Santa Cruz.

The talk was timely. This week, New York state agreed to several changes that would limit the use of solitary confinement for disciplining some groups of inmates, including those under 18 or pregnant women. The agreement stemmed from a class-action lawsuit.

The New York State Department of Corrections provided to CNN a statement from its acting commissioner, which read in part: "These are important reforms that will make the disciplinary practices in New York's prisons more humane, and ultimately, our state's criminal justice system more fair and progressive, while maintaining safety and security."

A department spokesperson said no statement was available on the general use of solitary confinement.

A brief history of solitary confinement

There are about 80,000 people being held in some sort of solitary-type confinement in the United States, Haney said.

Prisoners in solitary confinement tend to be restricted to cells of 80 square feet, not much larger than a king-size bed, Haney said. Sleeping, eating and defecating all take place inside that space. For exercise, prisoners in solitary confinement often get a short time in a cage rather than an outdoor yard -- perhaps one hour per day.

Haney, who has studied prisons and punishment for more than four decades, estimates that about one-third of people in solitary confinement in this country are mentally ill, although some prison systems do not permit mentally ill inmates to be placed in solitary confinement.

Solitary confinement was used broadly in the 19th century, but the punishment was then largely abandoned because of the view that "it was doing more harm than good," Haney said.

Correctional practice began to reincorporate solitary confinement in the late 1970s and 80s, as prisons began to get overcrowded, Haney said. He believes prison systems turned to solitary confinement as a short-term solution to controlling disruptive or violent behavior, lacking the resources to provide positive incentives or programming.

But overcrowding in prisons turned out to be permanent and mostly increased each year.

Prison systems continued to struggle over what to do to resolve conflicts or stop violence or disruption in the institutions. They put more prisoners in solitary confinement and left them there for longer periods of time, Haney said.

"I think the cost of solitary confinement is now being critically examined and rethought, and prison systems are beginning to ask themselves whether this is worth it, and whether or not it does not create more harm than good," he said. "Courts are pushing them to consider the inhumanity of the practice, as well."

'Prison wasn't in me'

King noticed six months into his time in solitary confinement that his eyesight significantly worsened -- he thinks because his eyes had become acclimated to such short distances in his cell. Over time, he retrained his eyes so that he would not be so nearsighted, he said.

Eye problems are not uncommon in these circumstances. In fact, Jules Lobel, professor at the University of Pittsburgh School of Law, said there is a swath of cataract surgeries at Pelican Bay Prison in California.

Lobel represents more than 1,000 prisoners at Pelican Bay in a lawsuit alleging that keeping prisoners in such conditions -- isolated in small, windowless cells with no physical contact or phone calls -- violates the Constitution and international law because it is "cruel and inhumane."

King, who was freed when his conviction was overturned 13 years ago, said his mental health suffered, too, but he knew others were faring worse and he was determined to not let that happen to himself.

"I was depressed every day I was in prison," he said. "I wanted to get out. I was in prison, convicted for a crime I didn't commit. Of course I was depressed."

Initially, food was served to him on a tray under the door to his cell; sometimes the tray was flung onto the floor with its contents spilled. King said he and other inmates filed a redress and went on hunger strikes until they negotiated that holes would be cut in bars to serve the food in a more sanitary way.

He said he and others also filed a lawsuit so that the prison would give them the opportunity for outdoor exercise. King could talk to other prisoners through the walls or by sliding notes.

"What helped me weather the storm was: I was in prison, but prison wasn't in me," he said.

What it's like

Solitary confinement has been associated with many different physical and psychological ills.

"When isolated prisoners are asked, they point to anger, hatred, bitterness, boredom, stress, loss of the sense of reality, suicidal thoughts, trouble sleeping, impaired concentration, confusion, depression, and hallucinations," writes Peter Scharff Smith of the Danish Institute for Human Rights in an essay published by University of Chicago Press.

Several studies point to headaches, heart palpitations, increased pulse and oversensitivity to stimuli as symptoms of isolated prisoners, Scharff Smith wrote, as well as dizziness, loss of appetite and weight loss.

Most studies on the topic have found depression and anxiety among isolated inmates, Scharff Smith wrote.

A study on the New York City jail system published this month in the American Journal of Public Health found that those who had been in solitary confinement at least once had a higher likelihood of self-harm.

Haney said identity disorders have also been found among isolated prisoners because of the loss of contact with the social world.

"People have to structure their lives around the absence of other human beings," he said. "They [prisoners in solitary confinement] go for years on end without touching anyone with affection."

Typically people released from solitary confinement don't get much help transitioning out of it, he said. Some systems parole prisoners directly out of their isolated cells.

Lobel argued at the AAAS conference that social interaction and sensory stimulation form a basic human need, as supported by science. Research has shown people outside of prison who are socially isolated also have a higher risk of heart attacks, hypertension, concentration and memory problems, he said.

"We're trying to integrate law and science in this," he said.

Solitary confinement and the brain

There aren't any direct brain-imaging studies of people who are in solitary confinement because of access issues, Huda Akil, a neuroscientist at the University of Michigan, said at the AAAS conference. But available studies on similar situations suggest significant brain changes could be occurring.

Positive experiences, including social interaction, have positive impacts on the brain, such as the activation of molecules called growth factors, which are akin to fertilizers for brain cells, helping them regrow and interact.

"Depriving people of that is physically depriving the brain from its nourishment," she said.

Without any social interaction, some people hallucinate or become explosive in their emotions, she said.

An absence of sunlight and being out of sync with the daily rhythm could produce negative effects by itself, she said. Several studies on shift workers have found associations with various medical conditions.

Severe depression has profound impacts on the brain; autopsies have shown that "the orchestration of brain and activity of genes in their brains is messed up" in such patients, she said.

It's a vicious cycle: You feel bad, that produces stress, stress hurts the brain, and that makes you feel bad, Akil said.

Chronic depression and stress have been associated with a shrinking of the hippocampus, a seahorse-shaped brain area critical for memory, spatial recognition and controlling one's emotions, Akil said. Studies have shown that the longer the depression goes untreated, the more the hippocampus shrinks.

"When Robert [King] tells you that he gets disoriented physically, I can tell him that people who are chronically depressed have a shrunken hippocampus, and that that affects your ability to orient in space, in 3D," she said.

King told CNN after the conference that this brain atrophy could be what is happening to him.

"The brain somehow won't register things, and it won't register exactly where I am," he said.

The Angola 3

King was one of three inmates known as the "Angola 3" who protested what they said were injustices at the Louisiana State Penitentiary at Angola. The three spent decades isolated in cells for 23 hours a day.

The other two, Herman Wallace and Albert Woodfox, were convicted in the 1972 killing of a guard at the Angola prison.

Wallace died just days after being released from prison in October 2013 at age 71.

"His legacy will endure through a civil lawsuit that he filed jointly with his fellow Angola 3 members, Albert Woodfox and Robert King," Rep. John Conyers Jr., D-Michigan, said in October. "That lawsuit seeks to define and abolish long-term solitary confinement as cruel and unusual punishment."

Former 'Angola 3' inmate dies days after release

Woodfox remains in prison, where he has been in solitary confinement for more than 41 years. Amnesty International USA has called for his release.

King was convicted in 1973 of killing a fellow inmate, although he believes he was "being punished for being a member of the Black Panther Party." He was transferred to Angola weeks after the security guard was killed, but was investigated as a possible conspirator in the slaying.

Today, King serves as an adviser to Solitary Watch, an online project devoted to news, firsthand accounts and research and reporting on solitary confinement. He has also campaigned for the release of the other two members of the "Angola 3."

King writes on his website: "I may be free from Angola, but Angola will never be free of me."

@highlight

About 80,000 people in the U.S. are being held in solitary-type confinement

@highlight

New York state agreed to limit solitary confinement for some prisoners

@highlight

Study showed solitary prisoners had higher likelihood of self-harm