Washington (CNN) -- It is a case at the intersection of science and finance, an evolving 21st century dispute that comes down to a simple question: Should the government allow patents for human genes?

The Supreme Court offered little other than confusion during oral arguments on Monday on nine patents held by a Utah biotech firm.

Myriad Genetics isolated two related types of biological material, BRCA-1 and BRCA-2, linked to increased hereditary risk for breast and ovarian cancer.

At issue is whether "products of nature" can be treated the same as "human-made" inventions, and held as the exclusive intellectual property of individuals and companies.

A ruling is expected by late June.

On one side, scientists and companies argue patents encourage medical innovation and investment that saves lives.

On the other, patient rights groups and civil libertarians counter the patent holders are "holding hostage" the diagnostic care and access of information available to high-risk patients.

How human genes become patented

Outside the court, several protesters held signs, such as "Your corporate greed is killing my friends" and "My genes are not property."

The justices asked tough questions, raising a number of colorful hypotheticals to explore the boundaries of patent law, including whether things like baseball bats, leaves from exotic Amazon River plants, and the human liver could get federal government protection.

"The patent law is filled with uneasy compromises, because on the one hand, we do want people to invent," said Justice Stephen Breyer. "On the other hand, we're very worried about them tying up some kind of whatever it is, particularly a thing that itself could be used for further advance."

Justice Anthony Kennedy noted Myriad made a significant investment in time and money in its genetic "discoveries" and might be allowed to have two-decade control over the genes for research, diagnostics, and treatment. "I just don't think we can decide the case on the ground: oh, don't worry about investment, it'll come" if there was no patent protection.

But Justice Sonia Sotomayor used a "chocolate chip" cookie analogy to say merely isolating naturally derived products would normally not get you a patent, only for the particular process or use of the cookie.

"If I combust those in some new way, I can get a patent on that," she said. "But I can't imagine getting a patent simply on the basic items of salt, flour and eggs, simply because I've created a new use or a new product from those ingredients."

The patent system was created more than two centuries ago with a dual purpose. One is to offer temporary financial incentives for those at the ground floor of innovative products like the combustible engine and the X-ray machine. The second is to ensure one company does not hold a lifetime monopoly that might discourage competition and consumer affordability.

All patent submissions rely on a complex reading of applicable laws, distinguishing between abstract ideas and principles, and more tangible scientific discoveries and principles.

Medical science had traditionally shunned patents.

A famous example cited in numerous briefs in the current appeal involved Dr. Jonas Salk's development and invention of the polio oral vaccine in 1952. When his life-saving treatment was announced, he said the people would "own" the vaccine, adding "Could you patent the sun?"

Maybe not the sun, but in the past 31 years, 20 percent of the human genome has been protected under U.S. patents.

All sides agree the science of isolating the building blocks of life is no easy task. Myriad has said it has spent several years and hundreds of millions of dollars in its research.

Since Myriad owns the patent on breast cancer genes, it is the only company that can perform tests for potential abnormalities. An initial test catches most problems, but the company also offers a second, separate test, called BART, to detect the rest, a diagnostic that can cost several thousand dollars.

"We invest heavily in the research and development that is needed to discover and provide high-quality molecular diagnostic products that save and improve patients' lives,'' said Richard Marsh, executive vice president and general counsel at Myriad. "Strong intellectual property and patent rights in the United States are critical to fulfilling our mission."

The company says 1 million patients have benefited from its BRAC Analysis technology, and that about 250,000 such tests are performed yearly.

And officials say the average out-of-pocket expense for the testing is only about $100, a figure disputed by the plaintiffs.

All sides agree too, the BCRA testing has saved countless lives since it was first unveiled in 1996, giving at-risk women the option of having their breasts removed as a preventive measure.

But some patients have complained charging so much for a second test is "irresponsible," and a sign the bio-tech company is more interested in profits than patient care for those unable to afford the second analysis. It is a charge the company strongly denies.

Among those challenging the Myriad patents are sisters Eileen Kelly and Kathleen Maxian. Kelly was diagnosed with breast cancer at age 40.

The initial BCRA test proved negative, meaning her family members were not likely at risk. But Maxian later developed ovarian cancer. The second BART testing proved positive, meaning the siblings carry the cancer-causing mutation all along.

"It could have prevented my cancer, or at least caught it early," Maxian told CNN's Senior Medical Correspondent Elizabeth Cohen. "Now my cancer is so advanced, I have only a 20-percent chance of being alive five years from now. I'm so angry."

Money was not an issue for them, but Kelly and Maxian, along with a coalition of physician groups and genetic counselors say Myriad has not made the BART tests widely available for patients without a strong family history of these kinds of cancers.

"Myriad did not invent the human genes at issue in this case," Christopher Hansen of the ACLU told the court at argument. He is representing the plaintiffs bring the initial lawsuit. "Myriad deserves credit for having unlocked these secrets. Myriad does not deserve a patent for it."

But several justices raised concerns.

"Isolating or extracting natural products has long been considered patentable," said Justice Ruth Bader Ginsburg, echoing what the company has argued - and won in lower courts. She offered examples like "aspirin and whooping cough vaccine. How is this different from those starting as natural products?"

Justice Samuel Alito used the example of a newly discovered plant with "tremendous medicinal purposes."

"It's not just the case of taking the leaf off the tree and chewing it" to treat breast cancer. "Let's say if you do that, you'd have to eat a whole forest to get the value of this. But it's extracted and reduced to a concentrated form. That's not eligible for a patent?"

Justices Elena Kagan and Antonin Scalia put a financial spin on the question. "Why would a company incur massive investment if it cannot patent?" an isolated gene, asked Scalia. When told by Hansen that scientific "curiosity" or Nobel Prize recognition might be enough, Scalia seemed unsatisfied. "Well, that's lovely," he said somewhat sarcastically.

On the other side Myriad attorney Gregory Castanias said "the parade of horribles" raised by the plaintiffs had not happened.

"There's no dispute in this case that there has been some alteration of the isolated DNA molecules." He said there has been an "explosion in biotechnology and the successful, economically successful, technologically successful, and life-saving industry that is at the heart of these inventions."

But Kennedy disputed Castanias' assertion this patent was deserved because of "different economic values" in cutting-edge genetic science-- and that patients did not have the "human ingenuity" of the BCRA test before Myriad developed it.

"Well, we could have said that with atomic energy, with electric, but so far the choice of the patent law was that we have a uniform rule for all industries," Kennedy said. "That avoids giving special industries special subsidies, which is very important it seems to me."

Chief Justice Roberts repeated the concerns of several colleagues, when saying the gene patents were much different from those for pharmaceuticals and other medical advances.

"There, you're obviously combining things and getting something new. Here you're just snipping [the genetic line], and you don't have anything new, you have something that is a part of something that has existed previous to your intervention."

The federal government is taking a somewhat middle ground: DNA itself is not patentable but so-called "cDNA" can be. Complementary DNA is artificially synthesized from the genetic template, and engineered to produce gene clones.

Use of this protein-isolating procedure, known as "tagging," is especially important in mapping and cataloguing the vast human genome.

Solicitor General Donald Verrilli also suggested Congress could create exceptions in the genetic or bio-tech testing arena, over so-called "use" patents for specific procedures.

The high court has addressed the broader issue before, and may use a 2012 decision to guide the current human gene case.

In the so-called "Mayo" case, the justices unanimously said patents could not be issued on observations of a natural phenomenon -- in this case a doctor's medical diagnosis of a patient's reaction to a drug.

"If a law of nature is not patentable, than neither is a process reciting a law of nature, unless that process has additional features that provide practical assurance that the process is more than a drafting effort designed to monopolize the law of nature itself," wrote Breyer for the court in Mayo.

The current case is Association for Molecular Pathology v. Myriad Genetics (12-398).

@highlight

Oral arguments held on case involving nine patents held by biotech firm

@highlight

Myriad Genetics isolated two types of material linked to hereditary risk for two cancers

@highlight

Conventional patents are held as the exclusive intellectual property of the inventor

@highlight

Question is whether products of nature should be treated similarly under the law