(CNN) -- The future of earthquake-ravaged nuclear power plant Fukushima Daiichi is still anyone's guess, but it's already triggered fears of subsequent nuclear disasters elsewhere.

As efforts continue to get radiation levels under control in the damaged facilities in Japan, several countries have expressed doubts about their own nuclear programs. And seven in 10 Americans say they're more concerned about a nuclear disaster happening in the United States than they were before, according to a recent USA Today/Gallup poll.

Are these fears justified? What are the real risks of nuclear power, both globally and in the United States? And what do we do with all of that nuclear waste?

Experts say that while nuclear power has generally proven relatively safe, it is important to question whether nuclear plants everywhere could cope with a two-fold natural disaster combination like the earthquake and tsunami that rocked Japan on March 11. A review of plants in that regard would be worthwhile, said Burton Richter, recipient of the 1976 Nobel Prize in Physics and professor at Stanford University.

As Japan moves toward stabilization of the Fukushima Daiichi plant, here are some larger issues to think about in terms of the future of nuclear energy:

Balancing risks and benefits

It makes sense that the public is frightened as workers continue to tame the situation at Fukushima Daiichi; people want to know that nuclear power is safe, Richter said.

But so far, although the Fukushima Daiichi site is not in the clear in terms of radiation inside the plant, the radiation levels outside the gate are still not high enough to do any harm to human health. President Barack Obama and numerous health officials have assured U.S. residents that while radioactive particles from Japan may be detected in the U.S., there will be no health consequences from it, as the particles will disperse over the more-than-5,000 miles separating the site from the U.S. West Coast. Point of comparison: Chernobyl, a far larger nuclear disaster that happened in 1986, is closer to New York than Fukushima Daiichi is to Los Angeles, and no health effects were felt in the United States from Chernobyl, either.

In the broader picture of nuclear power, if you look at all of the risks to human health involved in energy production from all parts of the process -- the mining, transport, refining, shipping and disposal of waste -- nuclear energy is the second most safe, with wind as the only source that's more benign, Richter said.

When it comes to greenhouse gas emissions, nuclear power also looks pretty good. Many studies have found that nuclear power's life-cycle carbon dioxide emissions are comparable to wind, hydropower and other renewable energy sources, and far lower than coal and natural gas plants. Depending on the technology, nuclear and hydropower have 50 to 100 times lower greenhouse gas releases than coal, according to the International Atomic Energy Association.

But these analyses don't take into account the emissions from the mining and transport of nuclear fuel, said Mark Jacobson of the department of civil and environmental engineering at Stanford University.

Investment in nuclear power could increase the proliferation of nuclear weapons, Jacobson said. Also, in his view, the risk of a serious malfunction such as at Chernobyl, Three Mile Island and Fukushima Daiichi is not trivial.

Ideally, there should be an electricity system drawing from a spectrum of energy sources, with nuclear as one of them, Richter said. All in all, there are costs and benefits that come with all modes of electricity generation.

"The public should be thinking about: Which devil do you want to live with?" Richter said.

The international retreat from nuclear power

We've recently heard from the leaders of several countries rethinking their nuclear programs. While reviewing safety is crucial, some of the response may be an overreaction, and in certain nations an actual pullback from nuclear energy may be impractical, experts say.

On Monday, German Chancellor Angela Merkel announced a three-month moratorium on the extension of the operation periods for German nuclear plants. Tuesday, she ordered that seven of the oldest reactors in the country be shut down so that their safety can be assessed. Switzerland also announced the suspension of development of new nuclear power plants.

Israel's Prime Minister Benjamin Netanyahu told CNN's Piers Morgan that he doesn't think Israel will pursue civilian nuclear energy in the coming years.

"The uncertainty of what will happen is the cloud that hangs over the people of Japan, and I think right now, hangs over the world. It certainly caused me to reconsider the projects of building civil nuclear power plants," Netanyahu said Wednesday.

This pullback from the international community is expected but, in the view of Gary Was, nuclear engineering expert at the University of Michigan, it's a knee-jerk reaction.

Some progress may slow in the nuclear power arena as a result of the Japan disaster, but certain countries, including Japan, rely heavily on it, and can't afford to drop it entirely, experts say.

"In a year or two, the public opinion will still be negative, but there are some energy realities that may dictate the future," said Najmedin Meshkati, nuclear safety expert at the University of Southern California in Los Angeles.

Before the disaster at Fukushima Daiichi, Japan had 54 operational reactors providing about 27% of the country's power, according to the U.S. Energy Information Association. The relatively low cost of nuclear fuel and reduced greenhouse gas emissions compared to fossil fuels has made nuclear power popular in Japan, Meshkati said. By comparison, about 20% of U.S. electricity comes from nuclear power, according to the U.S. Energy Information Association.

The decision of sources of power is a country-specific one, but power has to come from somewhere, and dropping nuclear power may force a country to buy additional electricity from another country, said Peter Hosemann, assistant professor of nuclear engineering at the University of California, Berkeley.

In Hosemann's view, China and India will continue building more and more nuclear facilities because they do not have enough natural resources to generate the power they need otherwise.

"With China, you can't feed 1.2 billion people with windmills or oil or something, not in that country, if you want to have the same living standards as we do here," he said.

The silver lining of the Fukushima Daiichi disaster is that the Japanese population may demand more scrutiny of the nuclear power industry there, Meshkati said. They may ask for more openness and transparency about where to place nuclear power plants and how to oversee their safety, he said.

"The negative public opinion has some merit," Meshkati said. "People should question the safety of these plants."

Where the fuel goes

Can U.S. nuclear power plants survive earthquakes? The answer is yes -- each one of them is designed to withstand an earthquake, without releasing any radioactive materials at all, up to the maximum projected seismic event at that plant, according to the Nuclear Energy Institute, an industry group in Washington.

But in Meshkati's view, the spent fuel pools at the 65 running nuclear power plant sites in the United States are "sitting ducks in terms of safety and security hazards." These are pools of water at least 20-feet deep where used nuclear fool is kept to cool. At Fukushima Daiichi, these have been big problems because the electricity needed to keep them cool was lost, allowing radiation levels to rise, after the earthquake and tsunami.

This used fuel could be extremely dangerous in the event of a natural disaster, as evidenced by what happened at Fukushima Daiichi, and could also be targets for terrorist attacks, Meshkati said. The danger is that the pools could catch fire, resulting in large releases of radiation.

Even if the U.S. decided to close all of its nuclear reactors tomorrow, there would still be the problem what to do with the spent fuel pools, he said.

Used fuel that has been cooled in a spent fuel pool for at least five years can be put into a container called a cask and surrounded with inert gas, providing leak-tight containment, according to the U.S. Nuclear Regulatory Commission. There have been no releases of radiation harmful to the public from this cask storage, or contamination, the NRC says.

One proposed solution for long-term storage of used fuel is Yucca Mountain in Nevada. President George W. Bush approved Yucca Mountain as the site to store the U.S.'s spent fuel and high-level radioactive waste, but President Barack Obama cancelled work on the project in 2009. Various scientists, politicians and others like the Chicago Tribune are calling for a revival of this project, in which more than $9 billion has already been invested.

Whether it's at Yucca or somewhere else, having a central repository of nuclear waste would be a better solution than keeping it at the individual nuclear plant sites, Was said. But that doesn't address the problem of the need to cool the used fuel for five years before moving it anywhere else. Perhaps a more important question is: Could fuel be cooled in a way that doesn't require the pool design?

Jacobson, for his part, isn't sure whether it's better to have all that waste centralized or decentralized; it's just a massive problem for future generations, he said.

"I think it just illustrates this massive hole we've gotten ourselves into by developing so much nuclear power at the expense of renewable energy," Jacobson said.

The bottom line

Transparency and a culture of safety are crucial for the nuclear industry, and there should be more international cooperation to promote these endeavors, Meshkati said. Because radiation travels beyond national borders, it's crucial to have a strong international collaboration.

"A nuclear accident anywhere is a nuclear accident everywhere because of the traveling fallout," he said.

@highlight

Nuclear and hydropower have lower greenhouse gas releases than coal

@highlight

Fukushima Daiichi is further from Los Angeles than Chernobyl is from New York

@highlight

Countries have expressed skepticism about nuclear power

@highlight

Yucca Mountain in Nevada is a proposed site to store used nuclear fuel in U.S.