The U.S. Department of Labor recently announced that the unemployment rate fell to 8.2%. That should have been a signal that jobs are coming back and that the economy is about to rebound. But, as many economists say, the numbers fell primarily because unemployed Americans have become so discouraged with trying to find a job that they've simply quit looking.

Because nearly one-third of the American middle class, mostly families with children, have fallen into poverty or are one paycheck away from poverty, it is paramount that we dissect the root causes of this mass disenfranchisement within the American workforce. This was the motivation behind "The Poverty Tour: A Call to Conscience," our 18-city bus tour that traveled across the country last year. It was designed to bring more attention to the plight of impoverished Americans.

These citizens do not fit the negative stereotypes and propaganda that we've heard during the Republican presidential primary contests. The candidates who have vowed to cut government subsidies speak of the poor as if their constituents had been exempted from the millions who, despite their middle-class identification and aspirations, now fall beneath the established poverty line.

The people we met aren't lazy or eager to live off so-called government entitlements. We spoke with formerly middle-class parents who were thrust into poverty when one or both lost their salaries. We heard the stories of single mothers and fathers, military veterans and former high-wage employees desperately trying to re-enter a workforce that no longer pays living wages.

Joann Cotton, a 54-year-old Columbus, Mississippi, resident, was one of those faces of poverty we met on the tour. Unemployed for three years, Joann has gone from making "$60,000 a year to less than $15,000 overnight." Her husband is disabled and dependent on medicines the couple can no longer afford. They rely on food stamps, which, Joann says, "is depressing as hell."

Receiving government aid, however, has not been as depressing as her job search. Joann says she has applied for at least 300 jobs. Even though she can barely afford gas, she drives to the interviews only to learn that the employers want to hire younger candidates at low wages.

The experiences have taken a toll: "I've aged 10 years in the three years that I've been looking for a job," Joann told us. "I want to get a job so I can just relax and exhale ... but I can't. After a while you just give up."

Like Joann, millions of Americans are just giving up on the possibility of ever rejoining the workforce. These frustrations reflect a reality that is unraveling the American identity. One of the most fundamental dictates in achieving the "American Dream" has always been a good job that pays wages decent enough to care for our families, buy a car and a home, and live reasonably comfortable lives.

What has caused so many to quit looking for jobs and, by extension, abandon the American Dream? We argue that a covenant has been broken with the American people. We live in a society where corporations put profits over people. We march to the beat of political leaders who have decided the richest 1% of the people in this country deserve generous tax breaks and preferential treatment while most of the 99% are forced to pay unbalanced shares of the tax burden and live on less and less.

Unemployment has been discussed in sound bites within the framework of the Great Recession. Reporters and pundits pontificate about the housing and home-lending fiasco, the collapse of Wall Street and the amount of construction, manufacturing and government jobs lost as a result of the market's economic downturn.

Yet economists and politicians propose failed remedies based on rebuilding and rebooting systems that have already dashed the American Dream for many. Economist Peter Morici, for example, suggests dynamic job growth will be sparked by increasing domestic oil production, tackling the trade imbalance with China, relaxing regulations for big businesses and curbing health care mandates.

Not only do these efforts lack the innovation necessary to meet the demands of a burgeoning world economy, they also do nothing to change the nation's capitalist equation that renders everyday Americans irrelevant.

"Fair trade" with China will not interrupt the transportation of construction, manufacturing and production jobs overseas in exchange for huge profits. Fat-cat executives running investment firms, banks, insurance, health care and pharmaceutical companies might like to curb health care mandates, but that approach certainly doesn't address the needs of Americans looking for decent wages and affordable health care.

The Supreme Court's regressive Citizens United v. Federal Election Commission decision in many ways validates a truism. The court basically ruled that corporations are people. And like all Americans, corporations have the free speech rights and can spend whatever they want on political ads without disclosing who they are or exposing their agendas. So, in a very real sense, corporations are people  -- super-rich, self-serving people who can use their billions to influence elections at the expense of, well, real people.

Most major corporations are run by the über-rich -- the same people who shipped American jobs overseas, broke the backs of labor unions, pay a fraction of the salaries once paid for manufacturing jobs, turned full-time work into part-time positions, and snatched health care benefits away from employees. And many companies have even established "unemployed need not apply" policies. In other words, if you don't have a job when it's time to apply, you can't get the job.

When the "need not apply" story broke late last year, more than 6 million Americans had been out of work for six months or more.

Talk about kicking people when they're down.

During our poverty tour last year, we met countless people caught in vicious cycles of looking for nonexistent jobs because their unemployment benefits were expiring or had run out, scraping change together for gas to go on interviews that may or may not pan out, and having to swap food stamps for cash to keep the lights or gas on in the house.

Frustrations are especially high among young people dealing with an 18% unemployment rate -- a more than 60-year high. We attended a town hall meeting in Detroit during our poverty tour where parents complained of 25-year-olds who came of working age before the Great Recession who have never had a job in their lives. The newly launched #FixYoungAmerica campaign is centered around the fact that 20% of young workers have been out of work for a year or longer, jobs are scarce, and the cumulative student loan debt is more than $1 trillion.

"Our generation has been hit far worse than any other," said Scott Gerber, 28, part of the group of young people who started the campaign. "We represent the broken dream of America, and we can't let it continue."

That dream has been broken for youths and adults all over the country.

Many single mothers have stopped looking for work for the sake of their children's health. Because of deficit budget cuts, states are either eliminating or tightening eligibility requirements for child care programs that used to serve the working poor. More cuts are on the way, but, for the moment, children of women on welfare have access to basic health care. But previously eligible low-wage-earning parents are now either denied assistance or their children are placed on interminable waiting lists. It has reached the point where struggling parents have to choose between a low-wage job and welfare so their children can receive basic medical attention.

A person can survive in the jungle for only so long before his or her spirit breaks. And the spirit of the American workforce is approaching a breaking point.

Today's staggering unemployment isn't the stepchild of the Great Recession. It is the illegitimate offspring of a long-abided system that places the profits and concerns of big business and the mega-rich above the rest of us. The cancer of greed has spread throughout the body of America and surgery based on pre-recession strategies won't cure the disease.

The inconvenient truth is that America itself is in need of a transfusion of economic equity and radical reform. Everyday people must recognize that their lives matter just as much as the lives of the rich. A workplace rooted in fundamental fairness that provides decent living wage jobs will allow frustrated, unemployed workers like Joann Cotton to breathe again, and give them a chance to become revitalized contributing members of society. It's time to resuscitate the American Dream.

@highlight

Writers: Jobless numbers fell, but many discouraged unemployed just quit looking

@highlight

Middle class is slipping into poverty, they say, and the few jobs left don't pay living wage

@highlight

Our society has lost covenant with people and made a pact with corporations, they write

@highlight

Writers: Only radical change for everyday people, not CEOs, will save American Dream