(CNN) -- Creativity has taken center stage in recent years, with a slew of books, articles and TED talks extolling the virtues of imagination and exhorting young and old to go out and exercise their creative muscle.

In a 2010 IBM poll of CEOs worldwide, creativity was identified as the single most important leadership trait for success, enabling businesses to rise above an increasingly complex environment.

The future belongs to "creators and empathizers, pattern recognizers and meaning makers," declared author Daniel Pink in the introduction to his best-selling book "A Whole New Mind: Why Right-Brainers Will Rule the Future."

Creativity also matters to our emotional well-being as we find our way in an uncertain, rapidly shifting world. Imagination underpins our ability to remain resilient during difficult and stressful times since creative people tend to be more tolerant of ambiguity and better able to come back from defeat.

And yet, despite its growing importance, creativity suffers from an odd sort of paradox. According to psychologist and Wharton management professor Jennifer Mueller, research shows that even as people explicitly aspire to creativity and strongly endorse it as a fundamental driving force of positive change, they routinely reject creative ideas and show an implicit bias against them under conditions of uncertainty. Subjects in Mueller's study also exhibited a failure to see or acknowledge creativity, even when directly presented with it.

It would appear that we suffer from a bias against creativity. But we are in denial about it, possibly because of what it may say about us.

"Because there is such a strong social norm to endorse creativity, and people also feel authentic positive attitudes toward creativity, people may be reluctant to admit that they do not want creativity; hence, the bias against creativity may be particularly slippery to diagnose," Mueller and her colleagues suggest.

Why the bias?

"Creativity is doing something differently than you've done before," says Beau Lotto, a neuroscientist and founder of Lottolab, a hybrid art studio and science lab. From an evolutionary standpoint, uncertainty was a bad thing. "If you weren't sure that there was a tiger in front of you, by the time you were sure it was too late," Lotto observes. "Our brains thus evolved to take uncertainty and make it certain."

Mueller says, "We are intolerant of uncertainty in general. The more creative something is, the more novel it is. And the more novel it is, the greater the uncertainty we are likely to have about its feasibility."

These negative associations tend to be unacknowledged, and there is evidence that they are unconscious, as in the case of executives who demand creativity but continue to reject creative ideas.

Herein, however, lies the dilemma: Creativity is what we need to help us get through times of greatest uncertainty and difficulty. And it's exactly during those times, perhaps when we need it most, that we are least likely to embrace creativity.

Imagination scares us because it demands a foray into the unknown. "But only by going into a space of uncertainty can we do anything new," Lotto says. "That is a tremendous challenge, isn't it?"

Another reason for the bias against creativity may be the perception that something can either be creative or practical, but that much more rarely can it be both. Many (and perhaps even most) people hold the belief that for every success story such as Steve Jobs, the "patron saint of the creative class," there are thousands (or more) chronically unemployed and underemployed "artists."

This belief gives rise to a duality, where practical and creative endeavors lead largely separate existences -- one slogged at during the workweek and the other indulged on nights and weekends, or dismissed as a luxury.

The creativity versus practicality dissonance also manifested in aspects of Mueller's research. She refers to the two separate mind-sets of the "why" people and the "how" people.

People focused on "why" tend to frame the world in more abstract ways. In general, they don't tend to have feasibility concerns. Those who are in a "how" mind-set, however, are so focused on feasibility that they are likely to overlook or dismiss creative ideas.

"Most boardrooms are all 'how,' and the 'why' is crushed," Mueller says. "This is why Steve Jobs was so remarkable. He had a solid grasp of the 'why' and was also able to overcome objections to the 'how.' He was able to overcome the reality distortion field."

The folly of seeking certainty

There are a number of problems with our obsession with creating certainty, and the most important is that certainty does not exist.

"Certainty is an illusion! A delusion!" Lotto says.

Or, as Clint Eastwood once said: "If you want a guarantee, buy a toaster."

The second problem is that the more we seek to create tools to make life predictable -- from packaged foods to Starbucks, GPS devices to smartphones, Yelp to Trip Advisor -- the more we diminish aspects of our brains capable of dealing with the unexpected.

"Technology is an amazing empowerment and a huge disablement," says Laura Richardson, principal designer at frog design. "We are losing our capacity for resilience."

Richardson is a big believer in the "MacGyver" manifesto. (MacGyver, of course, was the ever-resourceful television character who was able to solve complex problems with duct tape, paper clips and any other material he found handy.)

"I remember being locked out of the house once when I was growing up," Richardson says. "I found an old ruler, somehow prodded up the window latch and got in. It was an amazing sense of accomplishment."

She says some of our best stories are about those times when we were forced into something and had to use ingenuity to find our way out.

Richardson says she believes that the future favors the flexible. She quotes MAKE magazine founding editor Dale Dougherty, honored by the White House as a Champion of Change, who wrote: "Our future security lies in knowing what we are capable of creating and how we can adapt to change by being resourceful."

Becoming comfortable with uncertainty

Is it possible to overcome our inclination toward the predictable?

Mueller notes an important exception to our avoidance of the unknown. Research shows that the framing of uncertainty changes the way people react.

"We don't mind uncertainty when it's associated with something positive, like hope," she says. "Frame something positively, and people will behave differently."

David Kelley, founder of the design firm IDEO, observes, "Creativity is being comfortable with having ideas and not fearing being judged when you put your ideas out there."

Kelley, recognized as one of America's leading design innovators, is passionate about democratizing creativity by helping people develop creative confidence.

He's not, however, teaching people how to be creative. "They are inherently creative," Kelley says. "All we are doing is taking away the blocks."

Those blocks form early, according to Kelley. Though young children are naturally and unabashedly creative, they either opt out of thinking of themselves as creative or have it hammered out of them in elementary school. "A kind of atrophy sets in, when they start to trust their analytical minds but not their intuitive minds."

Removing those blocks has a great deal to do with fear. He suggests approaching the fear of creativity the same way you would approach any other kind of phobia, such as the fear of heights or snakes.

Kelley finds that creative confidence carries over into other aspects of people's lives -- in the way they solve problems, sing karaoke, throw dinner parties. "Once you have done something dangerous and succeeded, you try it in other places. And you begin to learn how to synthesize your experience and intuition to make complex and important decisions."

With the challenges we are facing, we need to rethink what creativity means, Richardson says. We need to expand what we mean by creative. Creativity is not just about painting or drawing or art. It is about problem-solving. It's the flexibility of your mind, the ability to see things that no one can see and envision something entirely different. We are creating the future, bringing about change. And there is something incredibly empowering about that.

@highlight

People routinely reject and show bias against creative ideas, Amanda Enayati says

@highlight

Poll of CEOs: Creativity is the single most important leadership trait for success

@highlight

People reject creativity because of uncertainly -- but it's needed to help us through uncertainty

@highlight

Innovator: Build confidence by treating fear of creativity like a phobia of heights or snakes