Washington (CNN) -- Asian security may figure greatly in this year's U.S. presidential election because of urgent questions about North Korea and enduring concerns over how best to manage a rising China and preserve American influence.

In addition to Asia's looming role in the global economy, specific recent developments ensure that Asia will surface as an issue during the final months of the U.S. presidential campaign.

Asian security issues should be debated during the course of the election, and they will be framed in terms starkly different from those likely to be heard among Asian experts ruminating at a conference. While foreign capitals and analysts will scrutinize campaign rhetoric for clues, they would do well to remember that governing is different from campaigning.

President Obama's announcement last year of a pivot to Asia underscores a long-term trend in which the United States is gradually placing greater priority on the Asia-Pacific region. Economic power is shifting from the Atlantic Ocean to the Pacific and Indian Oceans, and emerging powers such as China and India are increasingly flexing their muscles as regional military and political powers.

Both Japan and South Korea, and Indonesia and its smaller neighbors in Southeast Asia, are all, to varying degrees, responding to these trends. Long-term plans are driven mostly by a rising China, uncertainty about America's long-term presence and increasing capacity for building local and coastal defenses and shaping regional institutions.

Obama's rebalancing of priorities toward Asia is designed to reassure allies and new partners, without overly provoking a China vital to the global economy.

For all its importance, however, the national political campaign has barely acknowledged the existence of Asian security. China has come under fire for currency manipulation and trading practices, and North Korea's Kim Jong Un managed to break into the campaign with his reckless missile launch. But the deeper, underlying issues of Asian security and their implications for the United States are awaiting more deliberate consideration.

Both candidates should make it clear how America's future peace and prosperity are intertwined with the Asia-Pacific region.

Here are 10 questions vital to U.S. interests that the presidential candidates should debate:

1. How should the United States manage relations with China?  How can the United States both engage in expanded trade and cooperation and hedge against China's growing military might? What is the best way to overcome China's increasing ability to deny U.S. military forces access to the East and South China Seas and old U.S. bases vulnerable throughout the Western Pacific? How can the United States retain overall cooperation while pressing China on military, political and economic issues? Does Washington risk being perceived in Asia as upsetting a delicate regional balance of power? How should the United States approach China's next leadership, including both its possible purging of Mao's Cultural Revolution but also its suppression of freedom? Does the recent ouster of the popular leftist politician Bo Xilai signify a moderating political trend or a pervasive corruption problem within the Chinese system?

2. How can the United States maintain sufficient military power and presence in the region? Recent budget cuts mean the U.S. Navy will remain under 300 ships and that air forces will not grow at the rates projected a year ago. Given budget constraints and limited basing options in the region, how can the United States retain a favorable military balance of power in the decade ahead and beyond? Should the United States further redistribute its military presence throughout the region, and, if so, where and how?

3. How will the United States make decisions over which arms to sell to Taiwan?  China is pressing hard to put an end to America's longstanding practice of trying to maintain a balance of power across the Taiwan Strait. Improved cross-Strait relations are in the interests of all parties, and yet they also make it more difficult to prepare for any future deterioration in relations. Under what circumstances should the United States sell Taiwan new, advanced F-16 aircraft or assist it with stealthier defenses such as indigenous submarine production or cyberwarfare?

4. What is the best strategy for checking North Korean ambitions to build long-range missiles and nuclear weapons?  How can the United States maintain deterrence and avoid miscalculation? Should missile defenses be strengthened? Should the United States allow South Korea to extend the range of its missiles from 300 to 800 kilometers? Should the United States and South Korea continue the move toward returning wartime operational control to Seoul by the end of 2015? What should the United States ask of China with respect to limiting North Korean provocations? Should the United States establish higher-level direct talks with North Korea's inner circle? What additional pressures, such as targeted financial measures, might be brought to bear on North Korean decision-makers?

5. Should the United States encourage Japan to take on more responsibility for regional security?  For example, how far should the Japan Self-Defense Forces go toward shifting its focus on its southwestern islands as potential checks on growing Chinese military capabilities? Should Japan and the United States more actively pursue combined operational concepts such as Air Sea Battle, which would seek to deploy maritime and air and possibly ground forces in tandem to counter the capabilities of potential adversaries? Are bases in Japan, especially the stationing of Marines in Okinawa, sustainable? What should be the role of the United States in defending Japan in the event of a conflict with China over the Senkaku/Diaoyu Islands in the East China Sea?

6. Should the United States play a more active role in ensuring peace in the South China Sea? What are the potential costs and benefits of building up the coastal defenses of nations such as the Philippines and Vietnam? How can the United States reinforce its alliance with the Philippines without provoking China or the region? Should the United States insist on a binding code of naval conduct for the region? Would ratifying the United Nations Convention on the Law of the Sea help? How should the United States work with the Association of Southeast Asian Nations, as well as larger forums such as the more inclusive regional discussions of the East Asia Summit and the ASEAN Defense Ministers Meeting-Plus?

7. How can the United States best balance support for current reforms under way in Burma/Myanmar with lingering concerns about the role of the military and ethnic conflicts?  Should the United States suspend sanctions as British Prime Minister David Cameron has recommended for the European Union? Can the United States make current reforms irreversible? How can the United States continue to maintain pressure on the government to follow through with, for example, democratic national elections in 2015?

8. How can the United States generally encourage allies and partners in the region to shoulder greater responsibility and expand security cooperation? For example, how can the United States work with others on energy and resource security for the countries of the region? What else might be done to shore up existing U.S. alliances, including with South Korea, Japan, Australia, the Philippines and Thailand? What other security partnerships, including with Singapore, India, Indonesia, Malaysia and Vietnam, deserve greater attention? Should the United States encourage India to play a more active role in East Asia? How far should the United States encourage allies and partners to improve multilateral security ties with one other?

9. How can the United States best protect an open global commons â€” the maritime, air, cyber and outer space arteries on which both commerce and security rest? With cyber and space threats far removed from the public eye, what should the U.S. government do, in tandem with the private sector and allies and partners, to ensure security in all these domains?

10. Finally, how can the United States best engage the Asia-Pacific region with respect to trade and finance, when the United States economy remains fragile, debt is increasing and unemployment remains high?  Is the Trans-Pacific Partnership a realistic framework for an inclusive, "gold-standard" regional trading regimeâ€”that is, one that would not just lower tariffs at the border but also deal with crucial issues such as protecting intellectual property rights and protecting the private sector against state-owned enterprises? What other policies would best ensure that U.S. leadership, presence and engagement in the region rest on a strong economic foundation?

Obama and Romney administration policies for the Asia-Pacific would be apt to overlap more than they would differ. But when it comes to making hard choices and implementing policies, leaders matter. And here it is worth noting that President Obama's Asia team in a second term would probably lack its most able senior official: Secretary of State Hillary Clinton, who has made her preference for returning to private life abundantly clear.

While these issues may not reveal a wide gulf in the views of the two candidates for president, they do serve to demonstrate America's growing stake in the Pacific Century.

The opinions expressed in this commentary are solely those of Patrick Cronin

@highlight

Patrick Cronin: Asian security issues have barely been discussed in campaign

@highlight

He says issues such as North Korea and China's growing power need discussion

@highlight

Cronin: How can diminished U.S. military meet challenges in the region?

@highlight

He asks whether Japan, other nations, can play a larger role