(CNN) -- For parents in Somalia, giving their children immunizations is not a choice.

In a country enduring more than 20 years of conflict, Somalia is home to one of the highest child mortality rates in the world, with one in five Somali children dying before their 5th birthday, aid agencies say -- in many instances, from diseases that could be prevented by vaccines.

Yet for some equally loving parents in the developed world, the messages surrounding childhood vaccination have become muddied. Some communities in areas previously considered disease-free are now falling below the levels of "herd immunity" required to protect against diseases such as measles, whooping cough and mumps.

This week, in Swansea, Wales, the local public health agency announced that 886 people have been diagnosed with measles in an epidemic that started in November. The outbreak has been attributed to low measles, mumps and rubella immunization rates. One man's death has been linked to the measles virus, while 80 people have been hospitalized.

In 2011, six people in France died as a result of a measles epidemic that neared 15,000 confirmed cases, according to the World Health Organization.

In 2010, a whooping cough outbreak, resulting from pockets of under-vaccinated people in California, resulted in 10 deaths, according to the California Department of Public Health. Nine of these were infants were too young to be vaccinated.

"We are extremely concerned about what's happening in some parts of the developed world," said Jos Vandelaer, chief of immunization at UNICEF, one of the groups helping vaccination efforts in Somalia. "In the developing world, many people don't even get the chance to be immunized. Health systems are not strong enough to take the vaccine to every child despite the fact that their parents want it."

Parents with real fears

Measles, whooping cough and Hib (haemophilus influenzae type B), along with many other childhood diseases, can be deadly, but they are vaccine-preventable. Measles alone killed more than 150,000 people globally in 2011, according to WHO.

Measles is also highly infectious, with one carrier likely to pass on the virus to between 14 and 18 other susceptible people, said Dr. Matthew Snape of the Oxford Vaccine Group in the pediatrics department at the University of Oxford, England.

Despite the severity of these diseases, some parents in the developed world choose not to immunize their children and accept the risks.

"Studies show that it is the upper middle class, well-educated Caucasian parents who are shunning vaccines," said Dr. Paul Offit, director of the Vaccine Education Center at the Children's Hospital of Philadelphia. "They have generally gone to graduate school, are in positions of management and are used to being in control."

A study released this month by the National Health Performance Authority in Australia reflected this trend. A number of affluent Sydney suburbs were identified as regions where low levels of immunity have put entire communities at risk from these diseases.

The reasons behind parents' decisions are complex. Part of the problem is lingering doubts around vaccine safety that were compounded by a retracted 1998 study linking the measles, mumps and rubella vaccine with autism.

Although declared an "elaborate fraud" by the British Medical Journal, it raised questions about the safety of immunization in the minds of many parents. These doubts then were spread worldwide on the Internet and in the media by anti-vaccination groups and some celebrities.

"If you want to scare yourself about vaccines, it's not that hard," Offit said. "Just turn on your computer."

For such parents, the perceived risks of vaccination outweigh the risks they associate with disease.

Vaccine-autism connection debunked again

In Australia, where vaccination is not mandatory, the anti-vaccination Australian Vaccination Network website says parents need to make an informed choice. The site offers links to articles and parental accounts of the potential side effects of many vaccines.

A UNICEF working paper released this week to coincide with World Vaccination Week has tracked the rise of anti-vaccination sentiment in Eastern and Central Europe and concludes that poorly managed immunization campaigns in some countries have also contributed to the problem.

Concerned parents in the affected countries are taking to blogs and Facebook, discussing their mistrust of vaccines and government programs, questioning the involvement of pharmaceutical companies and often recommending alternative medicine.

A March survey conducted by the U.S. organization Public Policy Polling showed that 20% of Americans believe there is a link between childhood vaccines and autism, and a further 34% were not sure.

Diseases long forgotten in the developed world

While there are some risks associated with vaccines, they are mostly minor, such as pain at the vaccine site or low-grade fever, according to the U.S. Centers for Disease Control and Prevention. A serious allergic reaction is rare and usually reported in less than one out of 1 million doses, the agency reported.

"Hundreds of millions of children every year are vaccinated, and the number of side effects we see is minimal," UNICEF's Vandelaer said. "The anti-vaccine groups focus on the potential side effects, not on the real side effects."

On the question of autism, numerous studies conducted over the past decade have all demonstrated there is no scientific link between vaccines and autism.

With so much conflicting information readily available to parents, Dr. Dina Pfeifer, program manager for vaccine-preventable diseases and immunization for WHO's Europe office, said she believes the decision of whether to immunize children has become so fraught that many parents choose to do nothing at all.

"They have a difficulty dealing with the amount of information for and against (vaccination) on the Internet, and out of this confusion they are failing to recognize the risks of the disease," she said.

Another factor driving parents' decision not to vaccinate is the security that comes with herd vaccination, as rates of immunization for many diseases remain above 92% for the population.

But Europe's recent battle with measles demonstrates the problems under-vaccinated populations can pose, especially with older children.

"Europe had 100,000 cases of measles from 2009 to 2012, and that shows how prevalent the pockets of un-immunized populations are in that area," Pfeifer said. "Almost 50% of those cases were older than 10 years of age, and the older you are when you contract measles, the more severe the course of the disease."

Another factor of these pockets is their affluence; these parents tend to be the ones able to afford overseas travel.

In 2008, a 7-year-old U.S. boy whose parents chose not to immunize him against measles traveled with his family to Switzerland. He caught the virus and returned to San Diego, unknowingly exposing 839 people to the disease and infecting 11 unvaccinated children, according to the journal Pediatrics.

In Europe and the United States, parents and most people under 45 have never seen the effects of diseases such as measles, diphtheria or polio.

"The fear factor (among parents in the developed world) is missing now -- the knowledge of what's on the other side if you don't have vaccinations," said Dr. Seth Berkley, CEO of the Global Alliance for Vaccines and Immunization, known as GAVI Alliance.

The lack of knowledge of these diseases is also a problem among younger doctors and pediatricians, who may not be able to identify the signs, resulting in misdiagnoses.

"There is a lot of value in case-based learning, but it is difficult to learn how to recognize these diseases if you haven't seen them before," said WHO's Pfeifer.

In contrast, most parents in the developing world, in places such as Somalia, have seen family members suffer, be maimed or die from such diseases, health advocates said.

Education and motivation

To address the problem, Berkley prescribes localized programs in countries to supplement the already high overall levels of immunization. Other physicians are supporters of parental education and want to ensure parents feel free to ask as many questions of their doctors and health care workers.

Dr. Steve Hambleton of the Australian Medical Association said further motivation may be necessary. "When you incentivize the parents in a meaningful way, whether it be financial or with other incentives, you can make an enormous difference in vaccination uptake," he said.

Berkley, a doctor who specializes in epidemiology and global health, said he has seen the devastating effects of vaccine-preventable diseases in war-torn countries and refugee camps.

Berkley said he wished he could take some parents in the developed world "on a tour, show them how horrible it is. Show them the illness that occurs out of these viruses."

"We've brought down child mortality dramatically with these vaccination campaigns and we are making dramatic progress, but the challenge is getting people to understand what the world was like before this."

@highlight

Childhood vaccination has become muddied for some parents in developed world

@highlight

More than 880 people have been diagnosed with measles in Swansea, Wales

@highlight

Diseases such as measles, whooping cough can kill, but vaccines are available