On Tuesday, three U.S.-trained scientists won the Nobel prize in physics, for finding definitive evidence that the expansion of the universe is accelerating.

Their discovery did not fit any existing theory, so it had mind-blowing implications for our understanding of the physical world. At the same time, it's relatively easy to explain to nonspecialists. So fasten your seat belts for a quick tour of this frontier of knowledge: What was the actual discovery, why is it important, and what does it mean for our world?

Flash back to the 1990s, when two independent research teams set out to "weigh" the Universe -- one led by Saul Perlmutter, a young physicist at the Lawrence Berkeley Laboratory, the other by  a Harvard professor of astronomy, Bob Kirshner, with former graduate student Brian Schmidt, now at the Australia National University, and then-graduate student Adam Riess, now a senior astronomer at the Space Telescope Science Institute and the Johns Hopkins University.

These astrophysicists knew the universe was a vast, mostly empty space, dotted with galaxies of stars in a thin sea of atoms. Thanks to work 70 years earlier by Edwin Hubble (after whom NASA's space telescope is named), they also knew the universe has been expanding for billions of years. Like all astronomers, they expected the expansion to be slowing due to the pull of gravity between galaxies and other matter.

It's pretty simple: The more stuff in the universe, the greater the gravitational "braking" of the expansion. So, the Nobel prize-winning experiments were designed to measure the rate of deceleration of the expansion, and thus the total amount of material in the universe.

What could go wrong? After all, gravity was the only known force that could play a role. Both teams measured the distances to supernovae in distant galaxies, expecting they would be closer to us than if there were no gravity at all.

Imagine the shock when the data indicated the expansion was speeding up. Supernovae appeared to be more distant -- fainter -- than if the expansion speed were unchanging.  What?! The accelerating rate of expansion signaled that gravity, a force we have known about and loved since the first apple fell from a tree, is a paltry thing compared to some new, utterly unknown, energy field that pushes galaxies apart.

We call this new thing "dark energy" -- signifying the energy that appears to push outward, with the adjective "dark" signifying that we know nothing whatsoever about its nature.

Moreover, in 2003, NASA's WMAP cosmology satellite showed convincingly that dark energy is the dominant constituent of the universe.

This stuff wasn't predicted by any physics theory and was completely unknown until the Nobel prize-winning teams of astronomers and physicists made their measurements -- yet there is more of it than anything else in the universe. More than the atoms that make up you and me and our Earth, more than the hydrogen and helium that pervades the universe, more than the unknown dark matter particles that cause attractive gravity and allow galaxies to form in the first place. Whatever it is, it's teaching us something utterly new about how matter and space and time behave. A fundamentally new physics theory is needed.

The fact is, dark energy is the biggest mystery in science. It has driven a huge amount of research in the past decade, and was a key driver in last year's "New Worlds, New Horizons" report from the National Academies of Science, which prioritized future astronomy and astrophysics projects. Making better measurements of the properties of dark energy was very high on the list, using the James Webb Space Telescope, now nearing completion, as well as an infrared-optical space telescope to be built in the coming decade.

Both teams measured the expansion rate using supernovae, which are stupendous explosions at the end of a star's fuel-burning life. Astronomers know that a certain type of supernova always emits roughly the same amount of light, meaning it is a "standard candle" that can be used to indicate distance. Fainter supernovae would be farther away, and brighter ones would be closer. To make their measurements of supernovae, the teams used telescopes around the world and in space, most run by the National Science Foundation and NASA.

A supernova's spectrum (how light is distributed across the blue-green-yellow-red optical spectrum) reveals the speed with which it is receding from us due to the expansion of the universe. You've probably noticed how the tone of a siren changes as it moves toward or away from you, and that the change is larger the faster the vehicle moves. Light emitted from supernovae shows the same kind of frequency shift, so its speed can be measured very accurately.

One more ingredient was essential for the experiment: the ability to look back in time. It takes a very long time for light to travel to us from these supernovae, which are rare occurrences in distant galaxies. Light from a nearby supernova might take hundreds of thousands of years to reach us, while light from the distant ones sought by the Perlmutter and Schmidt-Riess-Kirshner teams travels for billions of years. This means that looking at supernovae or galaxies at different distances maps the expansion history of the universe -- that is, the rate at which it was expanding at different times in the past. Measuring the change in expansion speed -- the deceleration -- was the experimenters' goal.

Instead the Perlmutter and Schmidt-Riess-Kirshner teams found the expansion was accelerating -- as unexpected as seeing a ball fall upward when you drop it.

New data were critical to the bizarre new picture. Adam Riess, using the Hubble Space Telescope to measure extremely distant supernovae, showed that earlier in the universe gravity was actually winning over dark energy -- that is, the initial big bang expansion of space was slowing down. Later, as galaxies moved farther apart, the attractive force of gravity between them weakened, and dark energy, which seems to be a constant property of space itself, took over. In today's universe, 13.7 billion years after the big bang, gravity is far weaker than dark energy. So Riess' discovery clinched it: Alternative explanations for the original discovery would not have shown this evolution from gravity-dominated to dark energy-dominated space.

Astrophysicists are hot on the trail of dark energy. A fellow physics professor asked me, following Yale's Leigh Page Prize lecture on dark energy by Saul Perlmutter, one of the Nobelists, "Doesn't this just keep you up at night, wondering what this stuff could be?" It's keeping a lot of us up at night.

What does this discovery mean for the rest of the world, for people not engaged in figuring out the laws of nature? Dark energy does not directly impact our lives, at least not now. Our galaxy has billions of years to go before dark energy could be strong enough to rip it apart.  Events move slowly on universe-al time.

But if history is any guide, understanding the physics of particles, space and time has proved incredibly valuable time and time again. Much of the technological innovation that drives our economy today is derived from physics discoveries decades ago, according to the 2006 "Gathering Storm" report from the National Academies of Science.

The development of the quantum mechanics theory of matter in the 1920s led to the electronics in today's computers, industrial and household electronics, from your iPod to your toaster. Diagnostic imaging used to discover cancers or other disorders has its roots in the scattering of light and particles by matter, as studied by physicists using particle accelerators. Astronomers led the development of electronic imaging devices which are now used widely in digital cameras. Airport X-ray scanners were built by a company run by astronomers interested in detecting X-rays from stars and galaxies. The list goes on and on.

When Brian Schmidt became an expert on supernovae, he was thinking about how stars explode, not a Nobel prize. When Adam Riess started graduate school, he was thinking about how the cosmos evolved to the present day. When Saul Perlmutter persuaded his laboratory to do his supernova experiment, he wanted to weigh the universe. When Bob Kirshner attracts hundreds of students to his astronomy classes at Harvard, he teaches them about distant objects and events that seem impossibly remote from our daily lives.

But their passion for science led to a Nobel prize-worthy discovery. It reminds us that the United States remains one of the leaders in cutting-edge scientific research and the training of future scientists. This discovery has challenged our very best theorists and attracted clever young people to science. And some day far in the future, understanding how dark energy could be a property of empty space throughout the universe may well have a profound impact on how we live back here on Earth.

@highlight

Three U.S.-trained scientists won the Nobel prize in physics last week

@highlight

Meg Urry says their findings documented the impact of "dark energy" in expanding universe

@highlight

She says dark energy is a force much more powerful than gravity

@highlight

Urry: Solving the mystery could have important practical applications