Washington (CNN) -- Most of us go about our daily business never thinking about the U.S. Supreme Court or the cases it decides. But sometimes, it gets a case so big -- and could affect your life so much -- you simply have to take notice. This week is one of those times.

The highest court in the land is preparing to tackle perhaps the most important appeals to reach it in more than a decade: the massive health care reform legislation championed by President Barack Obama.

The court will soon hear six hours of oral arguments over three days on the law's constitutionality -- and your health and your finances could be on the line. Their eventual rulings in an election year will not only guide how every American receives medical care but would also establish precedent-setting boundaries of government regulation over a range of social areas.

"The implications in the health care litigation are impossible to overstate," said Thomas Goldstein, a prominent Washington attorney and publisher of SCOTUSblog.com. "It has tremendous consequences for President Obama's re-election because it's a signature achievement. But in terms of law, this case is really going to decide how much power Congress has to regulate spheres that we've often thought of as the jobs of the states or of just individuals."

A century of federal efforts to offer universal health care culminated with the 2010 passage of the Patient Protection and Affordable Care Act. After months of bare-knuckled fights over politics and policy, the legislation signed by Obama reached 2,700 pages, nine major sections and 450 some provisions.

The U.S. Supreme Court: How it works

The partisan debate around such a sweeping piece of legislation has encompassed traditional hot-button topics: abortion and contraception funding, state and individual rights, federal deficits, end-of-life-care and the overall economy. The high court now gets the final word.

"These issues are really central to whether the federal government can regulate anything it wants to, or whether there are some things that only the state governments can regulate," said Paul Clement, the attorney who will argue against the law, on behalf of a coalition of 26 states.

On the other side are progressives who back the Obama administration and its congressional supporters.

"Congress thought it necessary to regulate the nearly 20% of our nation's economy that makes up the health care industry and to make sure insurance companies did not discriminate against people with pre-existing conditions, for example," said Elizabeth Wydra, chief counsel at the Constitutional Accountability Center. "That is squarely within Congress' authority."

Your guide to the arguments

Debate comes down to four key issues

Despite its complexity, the high court has narrowed its focus to just four key issues:

One: Constitutionality of the individual mandate (also known as the "minimum coverage" requirement), the key funding provision.

Two: Whether the individual mandate is a "tax," thereby limiting authority of the courts to immediately decide the mandate question.

Three: Whether other parts of the law can survive if the mandate is struck down.

Four: Federal vs. state conflict over expansion of the cooperative Medicaid program.

It is the "individual mandate" that has sparked the most controversy. It requires nearly every American to purchase some level of insurance or face a tax penalty of up to about $700 a year.

Typical of the ideological divide, the opposing sides do not even agree on what the individual mandate was designed to accomplish. Supporters see it a way of spreading health care costs to a larger pool of individuals, ensuring affordable, quality medical care. They say regulating commerce and the economy has long been a federal prerogative.

Health law supporter: 'It really is going to help the American public'

The Justice Department will tell the high court that since every American will need medical care at some point in their lives, individuals do not "choose" to participate in the health care market. Federal officials cite 2008 figures of $43 billion in uncompensated costs from the millions of uninsured people who receive health services, costs that are shifted to insurance companies and passed on to consumers.

Health law opponent: 'Congress made a bad situation worse'

But opponents see a fundamental constitutional violation, an intrusion into citizens' personal lives, forcing Americans to purchase a commercial product they might not want or need. The states equate such a requirement to a burdensome regulation of "inactivity."

One federal appeals court has found the act unconstitutional. Two others have has said it is a proper exercise of congressional mandate. A third court has ruled against the states on technical grounds, saying local officials lack authority to even go into to court and argue the individual mandate issue. Twenty-eight states and countless individuals and groups have sued the administration.

What the reform is designed to do

Health care reform, a top Democratic priority since the Truman administration, was passed by the previous Congress in a series of close party-line votes. Obama signed the act into law in March 2010.

Among other things, the measure was designed to help millions of uninsured and underinsured Americans receive adequate and affordable health care through a series of government-imposed mandates and subsidies. The federal government will tell the court that 45 million Americans last year lacked health insurance, roughly 15% of the country's population.

Critics have equated the measure to socialized medicine, fearing that a bloated government bureaucracy will result in higher taxes and diminished health care services.

Opponents derisively labeled the measure "Obamacare." Republican leaders, who captured the House of Representatives in the 2010 midterm elections, have vowed to overturn or severely trim the law. All the major GOP candidates for president have echoed similar calls, especially in their TV campaign ads. That has concerned some liberal legal analysts.

"It seems what the conservative state attorneys general and the governors were trying to do was seek a do-over of the act in the courts, to achieve what they couldn't in the legislature. And it really has become a bit of political theater," says Wydra. "If the Supreme Court and especially some of the conservative justices uphold the mandate, and deliver the message to the tea party that their constitutional vision is fundamentally flawed, that makes it much harder for tea party candidates and their supporters to have their constitutional theories taken seriously by the American people."

Supreme Court and election-year blockbusters

But the states worry how far the federal government would go in the future, all in the name of regulating "commerce," if the high court found the law constitutional.

"I think about just a couple of years ago when the automobile industry was suffering, and Congress said: we're going to give people incentives to buy new cars," said Clement. "Well, it would have been even more effective and even better for the car industry if Congress had just said: if you make more than $100,000, you need to buy a new car. They haven't done that, maybe it's self-restraint, maybe it's because the [sweeping] power really doesn't exist. That's really what the court is going to decide."

How the justices could rule

The entire court of nine justices will hear the case, despite separate calls for Clarence Thomas and Elena Kagan to recuse. They will have several options before them when issuing opinions in these cases.

They could separately strike down or uphold the individual mandate and Medicaid provisions and rule whether the entire law must be scrapped. Or they could declare a legal "time-out"-- concluding the constitutional questions must be postponed until the major provisions go into effect in 2014, when any real "harm" from the financial mandates would presumably be felt.

Two families, two viewpoints on health reform

The opportunity to rule on a landmark case brings with it precedent-setting opportunities to either expand or deflate not only the power of Congress and the executive but also the judiciary's own prestige and authority. In some ways, it is a perilous path, since the courts have increasingly become a political football.

"We're in a little bit of a political death spiral for the Supreme Court, as ideologues on the left and right attack justices with whom they disagree, maybe decreasing the public's confidence in the Supreme Court," said Scotusblog.com's Goldstein. "And as they take up health care, abortion cases, immigration -- all of those issues -- there are going to be more excuses to attack the justices."

So expect nine unelected judges and the tricky issues such as health care they confront to be major talking points in this year's state and federal elections. Their votes could ultimately decide whom Americans choose on Election Day 2012.

"Our job on the court is to decide -- and control our stress," Justice Stephen Breyer told CNN a couple of years ago while discussing how to manage -- personally and professionally -- the biggest, most politically explosive Supreme Court appeals. "Keep yourself under control. And do your best on the decision."

That's wellness advice that could serve the nine-member bench -- and anyone passionately folllowing the case -- in the days to come.

Read more about the rulings for yourself

The cases are Dept. of Health and Human Services v. Florida (11-398); National Federation of Independent Business v. Sebelius (11-393); and Florida v. Dept. of HHS (11-400). Rulings are expected in June.

@highlight

Court prepares to tackle perhaps the most important appeals to reach it in more than a decade

@highlight

Rulings could establish precedents in regulation over a range of social areas

@highlight

SCOTUSblog editor: "The implications ... are impossible to overstate"

@highlight

Constitutionality of the reform's individual mandate is a key point of the case