(CNN) -- With more than 5 million people suffering from Alzheimer's disease in the United States, a number that's expected to rise to 16 million by 2050, the pressure is on to find better methods of diagnosis, treatment and prevention.

Around the world, Alzheimer's disease is the second most feared disease, behind cancer, according to a recent survey of five countries conducted by the Harvard School of Public Health.

Yet there is still a lot of misinformation: Only 61% of Americans who responded to the survey correctly identified Alzheimer's disease as a fatal illness. Many participants also mistakenly believe there are sure diagnostic methods and effective treatments to slow the disease, but most would seek medical attention if they became aware of their own early signs.

The research that came out of the Alzheimer's Association 2011 International Conference on Alzheimer's Disease, which took place in Paris last week, reflects a growing emphasis on early detection.

Research suggests the best targets for exploring treatments are patients who do not have full-blown Alzheimer's disease, but experience mild symptoms. Scientists have identified biological indicators called biomarkers that seem to be associated with Alzheimer's, although they are not perfect predictors.

Alzheimer's Association: 10 signs of Alzheimer's

"Things are heading earlier and earlier. And the use of biomarkers has been really essential for helping everybody move toward an understanding of what the earliest changes are and when they can be detected," said Dr. Allan Levey, chair of neurology at Emory University School of Medicine.

Early detection

So far, no drug has been developed to significantly slow the progression of the disease in all patients. And there's no way to halt or reverse the decline of memory and other cognitive abilities once Alzheimer's has been diagnosed. Since attempts to help patients who already have symptoms in these ways have failed, scientists must look to the earliest stages of Alzheimer's in hopes of stopping it before it begins.

Studies presented at the conference reinforced the notion that signs of Alzheimer's may develop in the brain 10 to 20 years before any symptoms begin.

A substance in the brain called beta-amyloid has been associated with dementia in people who have those kinds of symptoms. This is the main ingredient of plaques that build up in the brains of Alzheimer's patients.

People with a rare genetic form of Alzheimer's, whose specific genetic mutations guarantee that they will develop the disease, tended to show signs of amyloid plaques in PET scans and cerebrospinal fluid 10 to 20 years before the onset of symptoms. These results come from the Dominantly Inherited Alzheimer Network project.

But that represents only a small fraction of Alzheimer's patients -- 1% of cases worldwide, specifically. If you don't have the genetic form, there's no way to tell if you will go on to develop the disease, even if you have accumulation of amyloid plaques. There are some people who have them but do not show symptoms of Alzheimer's.

The kinds of tests that would detect beta-amyloid levels are not widely available. And it's not clear that pulling the amyloid plaques out of the brain reverses the process of cognitive decline; this is one area of research right now.

Another biomarker of interest is a protein called tau, implicated in the neurofibrillary tangles -- which basically take the shape of cells and destroy them -- that build up in the brains of Alzheimer's patients, particularly in the memory center called the hippocampus. But there's no scan to detect these tangles in a living patient.

A major focus of research on early detection is patients who have mild cognitive impairment, a collection of symptoms involving difficulty with memory, language and other mental functions, but which does not interfere with everyday life. It is not necessarily a precursor to Alzheimer's disease, but it does raise the risk of progressing into that more severe illness.

Understanding mild cognitive impairment is important in coming up with better treatments for dementia in general, because the brain hasn't deteriorated as much as in Alzheimer's, so it may not be too late to intervene, experts say.

The brain is the primary organ the disease attacks, but a small study presented at the conference suggests the eyes may also reveal signs of Alzheimer's. Researchers looked at photos of retinal blood vessels and found some differences in Alzheimer's patients, but further research is needed to confirm this idea of using an eye exam to help diagnose Alzheimer's. The same holds for a study suggesting that falling is indicative of Alzheimer's early stages: It's a preliminary idea that needs further investigation.

Identifying risk and prevention factors

Another area of focus is identifying risk factors for Alzheimer's disease. These are associations, not known direct causes.

"Age is a risk factor we can't modify, at least yet. Our genetics, we can't modify yet, which is another major risk factor," Levey said. "But certainly seeking clues about ones that are modifiable is an important" research area.

At the Paris conference, researchers said 3 million cases of Alzheimer's could be prevented worldwide if lifestyle-based, chronic disease risk factors were reduced by 25%. This estimate is based on a mathematical model.

In the United States, physical inactivity had the biggest association with Alzheimer's out of the risk factors studied, followed by depression and smoking. Midlife hypertension, midlife obesity, low educational attainment and diabetes are other risk factors.

"If we can demonstrate that these risk factors can be modified, and that it will lead to lower rates of Alzheimer's disease, the impact could be huge," Levey said.

People in their 40s and 50s have still got perhaps a couple of decades to modify lifestyle to potentially lower risk, he said.

There is also growing evidence that head trauma may increase the risk of dementia. One study presented at the conference in Paris found that traumatic brain injury was associated with dementia among older veterans.

A study of former NFL players suggests that football players also may be at increased risk for mild cognitive impairment or similar cognitive decline, perhaps as a result of repeated head injury during these former athletes' sports careers. In fact, 75 former professional football players are suing the NFL, alleging that the league concealed information about the harmful effects of concussions on the brain for decades.

There is also the idea of cognitive reserve: that keeping the mind active can at least delay the onset of dementia. It also seems that intelligence might help the brain stay in the mild phase of the disease longer, although more study needs to be done in this area as well.

"We know that highly intelligent people have more tolerance to plaque buildup and to loss of energy in their brains than people with lower levels of intelligence and less education," said Dr. Steven DeKosky, vice president and dean of the University of Virginia's School of Medicine, at an Alzheimer's forum at the National Press Foundation in May. "Their brain basically fights it off and finds some other ways to get the things done."

Caregiving

One of the underappreciated effects of Alzheimer's disease is how great a toll it takes on caregivers. Caregivers are much more frequently ill and die earlier than people who do not care for someone with the disease, studies have shown. The stress of taking care of someone chronically ill is sometimes called caregiver syndrome.

Caregiving is hazardous to health because of the stress of helping Alzheimer's patients, and because caregivers may ignore their own health, DeKosky said.

"Alzheimer's patients, when they get into moderate and severe stages, don't have some real sense of time," DeKosky said. "They have to be watched every minute."

Patients may hurt themselves or wander off if not under constant supervision. And it's common for patients to reverse their sleeping and waking cycles, so caregivers' daily habits are likewise disrupted.

The cost is staggering: Caregivers provide more than $200 billion in unpaid care, 17 billion hours each year, according to the Alzheimer's Association.

Gibbons' advice to Alzheimer's caregivers: Breathe, believe and receive

Why don't we know more?

Two of the biggest obstacles to finding treatments for Alzheimer's disease are lack of money and difficulty enrolling people in clinical trials, experts say.

The United States spends $450 million each year in Alzheimer's research money, compared to $6 billion for cancer, $4 billion for heart disease and $3 billion for HIV/AIDS research.

In spite of the money that does exist for research, Alzheimer's clinical trials are hard to fill with participants, said Dr. R. Scott Turner, director of the Georgetown University Memory Disorders Program.

Sometimes people believe they're just having "senior moments" and don't want to acknowledge their illness, Turner said. In other cases, patients don't want to go through the hassle of the trial if they're not guaranteed to receive an experimental drug; but, in order for a scientific study to be valid, patients must be randomly assigned to either the drug or a placebo.

Also, some trials don't test drugs at all, but simply look for those biomarkers that may help predict disease later or explore other early diagnostic methods. Such methods will be in high demand when an effective treatment is developed, DeKosky said.

"When the first drug is successful, let's say in symptomatic disease -- may it be so -- the crush to take advantage of what we know, while it's still in research format now, will be immense," DeKosky said.

If you or a loved one are interested in exploring clinical trials, the Alzheimer's Association runs a system called TrialMatch to assist in finding a trial near you.

Follow cnnhealth on Twitter

@highlight

Survey: Alzheimer's disease is the second most feared disease, behind cancer

@highlight

Physical inactivity, depression and smoking are risk factors in the U.S., study says

@highlight

Emphasis in research is on early detection and identifying biomarkers