Syria's conflict erupted in March 2011 when President Bashar al-Assad's Alawite minority-dominated government launched a crackdown against a predominantly Sunni protest movement that grew into an uprising with an armed resistance. One year later, what is the situation, and what may happen next?

How did the unrest start?

The spark began in the southern Syrian city of Daraa with the arrests of at least 15 children for painting anti-government graffiti. Outrage over the arrests and the government's humiliating and violent reactions to their complaints emboldened the opposition and helped it spread. By mid-March protests were occurring across Syria.

How Syria's unrest unfolded

The government launched a full-scale siege on Daraa April 25, with other towns, including Homs -- the country's third-largest city --  following. Mass arrests unfolded and tales of torture spread across the country. The protest movement grew and solidified.

Paul Salem, director of the Carnegie Middle East Center, believes "it's conceivable that if the events didn't happen in Daraa," the uprising "might not have occurred."

But the deep-seated political and economic reasons underlining Syrian discontent was an omen. Protest in Syria was "going to happen" at some point, Salem said.

Initially, protesters wanted basic reforms, more freedoms, a multi-party political system and an end to emergency law. The regime introduced some reforms, but they were too little, too late. Protesters now want the al-Assad regime out and true democratic elections. Al-Assad has been in power since 2000; his father, Hafez, ruled Syria for three decades.

Read Bashar al-Assad: President defined by violence

What is happening now?

The 12-month-old conflict shows no sign of abating. More than 8,000 people have now been killed, including many women and children, the U.N. said this month. Opposition activists put the toll at more than 9,000. Thousands more have been arrested or have disappeared, while about 30,000 Syrians have fled to neighboring countries.

CNN cannot independently confirm reports of casualties or attacks in Syria because the government has severely restricted the access of international journalists. But reports from inside Syria indicate the regime is slaughtering civilians to wipe out dissidents seeking al-Assad's ouster. Al-Assad's regime routinely insists "armed terrorist groups" are behind the bloodshed in Syria.

And the rebels' tactics seem to be changing too. Videos show that jihad appears to have come to Syria with attacks on government forces that closely resemble jihadist tactics that are the hallmark of al Qaeda.

How has al-Assad survived?

Many analysts admit they under-estimated the Syrian leader's powers of survival. "Al-Assad proved us wrong on multiple grounds and is far more durable than we thought," Fawaz Gerges, professor of international relations at the London School of Economics, told CNN. "He's not only weathered the offensive and absorbed the shocks, but he's gone on the attack to try to crush the armed wing of the uprising."

Unlike former Egyptian and Libyan leaders, Hosni Mubarak and Moammar Gadhafi, who were both deposed after uprisings in their countries, Al-Assad has adapted to the situation in his, Gerges said, and is in no immediate danger. "His security apparatus has held its ground, and there have been few defections from the top elite in the military and security services."

So the momentum the Syrian rebels had during the Arab Spring has slowed. One reason was because of the assumption that the regime would not use the level of force it has, said Chris Phillips, lecturer in international relations at Queen Mary, University of London. "Initially al-Assad had to fabricate the existence of an armed opposition in Syria, but the emergence of such groups gave the regime pretext to crack down so heavily."

What external factors are in play?

The Syrian regime has come under international pressure to stop the crackdown -- the U.N., the United States, the European Union and some members of the Arab League have called for President al-Assad to step down -- but so far there has been little action.

Many Western countries have imposed sanctions, but the U.N. Security Council has failed to agree on a resolution calling for al-Assad to go. Arab and Western diplomats voiced their support for a draft resolution calling for a halt to the crackdown, but representatives from Russia and China vetoed it in October.

Russia -- which, like China, is one of the five veto-wielding permanent members of the Security Council -- has said it is concerned about a Syrian civil war and does not want al-Assad ousted. It has proposed its own draft resolution that assigns equal blame for the violence on both al-Assad and the opposition.

Syria's neighbors are concerned about an influx of refugees. Jordan's King Abdullah called for al-Assad to step down, the Arab League suspended Syria's membership, and Turkey, one of Syria's largest trading partners, imposed sanctions and threatened to cut off Syria's electricity. But crucially Iran's Shiite leadership remains loyal to al-Assad, who is an Alawite, an offshoot of Shia Islam that is in a minority in Syria.

"Syria is caught in the middle of a regional crisis," said Gerges. "On the one hand there's Iran and on the other, Saudi Arabia and the Gulf countries. One must also never under-estimate the lengths that Russia will go to in standing behind the regime."

With videos posted on social media providing much impetus for the uprising, Tehran's help is vital, analysts say. "Iran is now supplying crucial intelligence on rebels who are posting YouTube videos as well as finance," said Phillips. "Russia and China are also providing diplomatic cover -- so we can see how al-Assad has deftly repositioned his international alliances to stay in power."

Is there any prospect of military intervention?

Last year, the U.N. Security Council voted to impose a no-fly zone in Libya and use "all necessary measures" to protect its people from Moammar Gadhafi. But there is no such appetite for similar action against Syria. "The Chinese and Russians are dead set against (intervention)," said CNN's Fareed Zakaria in a recent blog post. "So it couldn't happen through the United Nations. There would be effectively a kind of unilateral or NATO operation with no international legitimacy."

And while there are calls for robust military intervention, that could be the worst possible thing to do, according to Rami Khouri, who runs the international affairs program at the American University in Beirut.

"I think foreign military intervention would probably be catastrophic, and to hear Americans suggest this is to think back what they did in Iraq and what an extraordinary catastrophe that has been," Khouri said on "Fareed Zakaria GPS."

Experts point out that while the opposition groups in Libya were relatively united and organized, the same cannot be said for rebels in Syria. Al-Assad also continues to hold  a vice-like grip on the country's security apparatus, and has the support of the army, one that is much stronger, better equipped and more unified than the one in Libya.

Geography must also be taken into account when considering intervention in Syria. Libya was relatively easy last year: most targets were near the Mediterranean coast and NATO air bases in Italy.

But Syria has a much smaller coastline than Libya (roughly 119 miles vs. 1,110 miles), and neighboring countries probably won't be so accommodating for supplies, troops or anything else needed in a possible mission.

Is the opposition united?

Weapons are flowing in, refugees are fleeing, but there seems little in the way of an organized Syrian opposition with which to work. And while Sunni Muslim neighbors such as Saudi Arabia and Qatar want al-Assad's removal, this seems more of an opportunistic anti-Iran strategy. Among the resistance forces are apparently some radical Sunni fighters, perhaps al Qaeda itself, and others whose ascension to power would likely cause a further crisis, with millions of Christians and other religious minorities fleeing from the region.

The failure of opposition groups to unite is the main reason the uprising has stalled, analysts say. "If I was the opposition, I'd look to the longer term," said Gerges. "They've presented a narrative to the outside world that al-Assad's days are numbered. They've spent time trying to get military intervention but not enough on unifying themselves into a cohesive group. They believe they're going to win in the end but at the moment they're divided both in and outside Syria."

The opposition has failed so far to win the support of wider sections of Syrian society, most observers believe. "The rebels haven't proved a credible force either politically or militarily," said Phillips. "The regime is easily a match for them on the battlefield, but crucially the Sunni merchant classes in cities like Aleppo have remained neutral."

What might happen next?

The conflict is likely to continue with neither side able to deliver a knockout blow. Analysts believe al-Assad is secure in the short-term with regional backing from Iran and wider diplomatic cover from Russia and China. But even if it defeats the opposition, Phillips said it is unclear how the regime can repackage itself. "It's very difficult to see how the opposition is going to topple al-Assad, but one must ask if he has alienated his core constituents so much that he cannot rule by consent?" he asked.

And the longer the conflict continues, the more fundamentalist Islamist elements will get involved, analysts say. "If it goes on some Syrians will turn to jihadi-style tactics," said Gerges. "I wouldn't be surprised if it eventually goes the way of Iraq although it's important to stress that the bulk of the armed response now is local Syrian, not al Qaeda."

In a recent blog posting, Fareed Zakaria pointed out that al-Assad drew an unfortunate lesson from the Arab Spring: "Don't waiver; don't make concessions; don't show weakness. In al-Assad's eyes, Egypt's Hosni Mubarak vacillated in his response to protests and ended up in prison. Libya's Moammar Gadhafi wasn't ruthless enough and ended up dead. Al-Assad has chosen to be brutal."

However he said in the longer term al-Assad's position is weak. For this reason, Zakaria said: "The government will not be able to fully suppress this revolt. The opposition will prove unable to completely overturn the government. The stalemate could go on for a long, long time."

@highlight

Protests across Syria began on March 15, 2011 after children's arrest for graffiti

@highlight

Opposition initially wanted reform; now it wants regime out and democratic elections

@highlight

More than 8,000 people have been killed, including many women and children

@highlight

Analysts say President al-Assad is safe in short term but less so further ahead