The U.S. Supreme Court on Monday began three days of potentially landmark oral arguments over the constitutionality of the sweeping health care law championed by President Barack Obama, with a majority of justices appearing to reject suggestions they wait another few years before deciding the issues.

In one of the most politically charged cases in years, the health care reform case drew people who waited in line starting Friday for the chance to attend, and sparked competing news conferences by supporters and opponents of the 2010 law passed by Democrats over united Republican opposition.

Hear oral arguments before the high court in the landmark case

The public sessions started Monday with 90 minutes of lively debate on a legally dense, but nonetheless important, question.

It boils down to whether the health care law's key provision is a "tax" that could prevent the court from considering the broader constitutional questions.

The key provision involved is the "individual mandate" requiring most Americans to purchase some form of health insurance or face a substantial tax penalty.

An obscure federal law known as the Anti-Injunction Act, which dates back to 1867, bars claimants from asking for a refund on a tax until that tax has been paid.

This "gateway" issue could stop the current legal fight in its tracks if the justices think the minimum coverage requirement amounts to a tax.

Several of them seemed reluctant Monday to take that route.

Read a transcript of the arguments

Justice Ruth Bader Ginsburg said the lawsuit being considered was about the constitutionality of a provision requiring the purchase of insurance, rather than a tax penalty.

"This is a suit that is challenging the 'must-buy' provision, and the argument is made that, if, indeed, 'must-buy' is constitutional, then these complainants will not resist the penalty," she said. "So what they're seeking is a determination that ... 'must-buy' is unconstitutional, and, if that's so, that's the end of the case. If it's not so, they are not resisting the penalty."

Justice Antonin Scalia, a conservative, seemed to agree, dismissing suggestions that a "parade of horribles" would happen if the court decided the larger constitutional questions now.

However, Justice Samuel Alito and Chief Justice John Roberts suggested a tax was indeed involved.

"The idea that the mandate is something separate from whether you want to call it a penalty or tax just doesn't seem to make much sense. It's a command. A mandate is a command," Roberts said, later adding: "It seems very artificial to separate the punishment from the crime. ... Why would you have a requirement that is completely toothless?"

In an unusual twist, the Obama administration is now siding with the law's opponents and strongly argued the mandate is not a tax. The high court actually designated a Washington private attorney, Robert Long, to argue in favor of the tax question.

Four mostly liberal members of the court -- including Obama appointees Sonia Sotomayor and Elena Kagan -- were aggressive in saying there was no tax at play here.

"Congress has nowhere used the word 'tax'. What it says is 'penalty'," noted Justice Stephen Breyer. "Moreover, this is not in the Internal Revenue Code but for purposes of collection. And so why is this a tax? I know you point to certain sentences that talk about taxes within the Code. This is not a tax to a tax. This is a tax to a health care requirement."

Citing the Anti-Injunction Act might give the court, particularly conservative members, a way out of deciding the explosive issue in an election year.

The majority might conclude the political branches can best resolve the conflicts, at least for now, or that the matter can be handled after the November elections.

Some court watchers have called this the health care "sleeper issue" that could potentially delay a decision on the constitutionality of the individual mandate for at least four years.

Monday's case was Department of Health & Human Services v. Florida (11-398). The larger, separate question of the individual mandate's constitutionality will be argued at the high court Tuesday.

The justices as a group seemed anxious Monday to move beyond the narrow issue of jurisdiction and address the larger constitutional questions. By the end of Monday's arguments, justices already were posing hypotheticals on other aspects of the law, including the individual mandate and state requirements to expand the Medicaid program -- questions to be tackled in the next two days.

Four big issues: Breaking down what the justices will tackle

Outside the court building Monday, supporters and opponents argued their own views.

"Everything this administration has done has moved us in the wrong direction, has created such a high level of uncertainty, reduced the confidence of the American people," said Republican Sen.  Ron Johnson of Wisconsin. "The Supreme Court has to do the right thing and rule this thing unconstitutional."

Democratic Rep. Robert Andrews of New Jersey said the high court should let voters decide through elections, instead of imposing a decision by nine justices.

"This court has a long tradition of deferring to the judgment of the voters, and that's what I think they will and should do here," Andrews said, adding that the health care law will "help a lot of people and help our country and that will be a great thing for our future."

A new CNN/ORC International poll Monday reflected the public divide over health care reform. The survey, conducted over the weekend, shows that the 2010 health care law is increasing in popularity, especially among independent voters, but half of Americans still oppose it.

According to the poll, 43% of Americans approve of the law, up five points from last November, with 50% saying they disapprove, a drop of 6 points. Of those who oppose the measure, 37% said it was too liberal and 10% said it wasn't liberal enough.

On the most controversial provision of the law -- a mandate requiring people to have health care coverage -- 51% of those questioned said they opposed it and 47% favored it, a gap within the survey's margin of error.

According to the Supreme Court, 110 members of the public -- almost double the initial estimate -- were admitted to watch Monday's arguments, along with 117 credentialed members of the media.

The justices know their eventual rulings could establish profound guidelines on the extent of congressional power and could shake up a presidential election year where health care has become a hot campaign topic.

"The social and political stakes just in this case in particular are quite significant, but even beyond that, there are broader constitutional principles," said Paul Clement, who will argue against the law before the justices. "This is a legal question and it's got a lot of people excited politically."

"The Affordable Care Act moves us very close to achieving health coverage for everyone," said Ron Pollack, executive director of Families USA, a health advocacy group. "It's my hope that the justices protect the law and allow the law to go into effect."

Health reform opponent: 'Congress made a bad situation worse'

Health reform supporter: 'It really is going to help the public'

Seats inside the court were scarce, both for interested parties and the public. Because of demand, the court's clerk told representatives from Congress, the Obama administration, the states and the dozens of private advocacy groups to decide among themselves who will attend.

For example, 26 states are leading the legal challenge before the Supreme Court, but there will only be room for six attorneys general to attend the arguments. Legal sources said those negotiations over the choices turned testy when some officials were not picked.

Blockbuster court rulings during election years

Sen. Max Baucus, D-Montana; Sen. Orrin Hatch, R-Utah; and U.S. Rep. Michele Bachmann, R-Minnesota, said they secured precious seats. Attorney General Eric Holder led the administration contingent.

And although it is little known, the justices themselves are allowed to give out up to nine tickets to anyone they want, so having an "in" with the bench might be the only way some interested parties will be admitted.

The Supreme Court: How it actually works

Dueling rallies and protests outside the court added to the charged atmosphere of a major legal case being heard in an election year.

All the Republican presidential candidates have said they would try to repeal the health care law if elected. One of them, Rick Santorum, did not attend the arguments, but he spoke on the courthouse steps afterward to challenge frontrunning rival Mitt Romney's support for health care reform in Massachusetts.

"There is only one candidate who has a chance of winning the Republican nomination who can make this the central issue that will be a winning issue for us to win the presidency back, and that is Rick Santorum," said the former Pennsylvania senator. "And unfortunately the worst person to make that case is Mitt Romney and that's why, as I say, we are here today and he is not."

Two families, two views on health care reform

In the three days of arguments, six lawyers will make their case in what are expected to be free-wheeling question-and-answer sessions characteristic of oral arguments. The main attorneys will be Clement on one side, representing the 26-state coalition opposing the law, and Solicitor General Donald Verrilli on the other, defending the law.

The public will be able to listen to the oral arguments on the court's website shortly after the sessions end.

In line to secure a rare and precious thing in D.C.

Frequently asked questions: A CNN guide to the arguments

The cases are Dept. of Health and Human Services v. Florida (11-398); National Federation of Independent Business v. Sebelius (11-393); and Florida v. Dept. of H&HS (11-400). Rulings are expected in June.

@highlight

New poll shows the public is divided on the health care issue

@highlight

"Rule this thing unconstitutional," says a GOP opponent of the law

@highlight

The Supreme Court should let voters decide, says a Democratic supporter

@highlight

The Supreme Court is poised to offer the final word on the constitutionality of health reform