Washington (CNN) -- Think big -- really big -- and you may understand the stakes in an upcoming Supreme Court case that could have a profound impact on nearly every American business with employees.

At issue is whether the justices should allow certification of the largest class-action employment lawsuit in U.S. history, a long-standing dispute against mega-corporation Wal-Mart Stores Inc. over alleged gender bias in pay and promotions. Arguments in the case are Tuesday morning and ruling can be expected by late June.

The company is the world's largest retailer and the nation's largest private employer. If the class-action goes through, hundreds of thousands of women -- perhaps as many as 1.6 million plaintiffs -- could join in the largest discrimination claim of its kind. Tens of billions of dollars or more in damages are potentially at stake.

The high court case is among the biggest of the current term, and could establish binding standards over high-stakes liability involving companies large and small.

'I'm a fighter'

A mammoth appeal started small -- six women from California, unknown to each other at first, but sharing a common story.

"I'm a fighter if nothing else, and so are all the other women that are involved," said Christine Kwapnoski, one of the original plaintiffs. Speaking with CNN, she recounted why she brought suit against Wal-Mart in 2001.

"I was saying I want to do something more, but for whatever reason I kept getting overlooked for team leader positions," she said. "They kept hiring men off the street. Literally, I don't even know where they came from, whether they came from college, men who never even had a day's worth of Sam's Club experience were coming in and I was the one training them."

Kwapnoski, 46, began working at Sam's Club retail warehouse -- part of the Wal-Mart brand -- in 1986, eventually relocating to a store in Concord, California. By 2000 she was the longest-tenured hourly employee at the store, but claims she was being paid "virtually the same" as male associates with half her experience. She was eventually promoted in 2001, two weeks after the lawsuit was filed, and remains at the company.

Kwapnoski soon realized her experiences were similar to other female workers -- first in the San Francisco Bay area, then across the country.

"They know we're right and they just don't want to admit it," she told CNN Correspondent Kate Bolduan. "They never want to admit anything when they're wrong, they just believe that they're semi-untouchable because of their size."

Kwapnoski claims she was told by a male general manager "to doll up," wear more makeup and dress a little better as a new supervisor on the loading dock, comments she says were inappropriate. And she says managers frequently yelled at her and other female workers, but not male counterparts.

The plaintiff's lawyer Joseph Sellers says there is a "corporate culture" at Wal-Mart, where female associates are treated as second-class employees, and that the company's "strong, centralized structure fosters or facilitates gender stereotyping and discrimination," which trickles down to individual stores.

"The store managers don't make up their own pay and promotion policy -- they follow a common set of policies that are established by headquarters in Arkansas," he said. "There is extensive oversight of the decisions they make."

Spokeswoman says people are held accountable

Wal-Mart operates 4,300 facilities in the U.S., with more than $400 billion in global sales in 2009. It employs 1.4 million people in the U.S. alone. Officials boast their anti-discrimination policy has been in place as long as the company has been around, and a recent public relations campaign has been launched to promote its diversity and inclusion.

Gisel Ruiz is an example of what Wal-Mart says is a person who started small but has risen in the company because of her talents and hard work. After beginning as a store management trainee nearly two decades ago in California, she is now executive vice president for people at Wal-Mart, responsible for human resources. Ruiz is also a spokesperson in corporate efforts to fight these claims of discrimination.

"From my personal experience, it's not part of the company's culture or part of the policies. My career growth has been very positive with Wal-Mart. I am in a job that I never dreamed that I would be -- it's based on my ability, my performance, my leadership abilities, but I am just one of many women," she told CNN. "I've never been exposed to the examples that have been shared by the plaintiffs. I simply haven't seen it and I will tell you that we don't have a tolerance for that kind of misconduct."

Ruiz says every employee from part-time entry level hourly workers to salaried managers must follow the rules.

"The policies against discrimination are in place for very good reasons; not only is the law, but is the right thing to do," she said. "There's oversight at a corporate level to ensure that the policies are in place, that they are relevant to today's workforce and today's workforce issues. Ultimately at store level, that's where those policies are enforced, and people are held accountable if they violate those policies."

Wal-Mart says case is too big

The workers bringing suit say women represent more than 70% of Wal-Mart's hourly workforce, but in the past decade made up less than one-third of its store management.

A federal appeals court had concluded there was enough merit in the claims to proceed to trial on a class-action track. Since the lawsuit was filed a decade ago, both sides of the dispute have held discovery hearings, where preliminary testimony was taken to establish facts.

The high court will not judge the merits of the sweeping claims at this stage, just whether a class-action trial can proceed. The parties have the option of settling the dispute out of court at some point in the future, and the company may feel great financial pressure to do if they lose at the Supreme Court on this gateway issue.

The company has protested the size of the class action, which it called "historic" in scope, saying it would be onerous, with too many disparate issues, to litigate.

"The plaintiff's lawyers in this case went way too far. It's the way the plaintiffs have framed the case, implicating every store, every person. There's no way, one woman can be representative of a million women in a case like this," said Theodore Boutrous, an experienced appellate attorney who will argue the case for Wal-Mart before the justices. "The danger is that it would expose virtually every company in America to huge, costly, baseless class actions that's bad for jobs, bad for the economy, and at the end of day it doesn't help the people on behalf the case is being brought."

The company has the support of the business community, while a variety of civil and gender rights groups and unions back the plaintiffs. The Obama administration has not weighed in on the case.

"Wal-Mart is arguing in effect there is a large-company exception -- that when the company is sufficiently large and the discrimination is sufficiently widespread -- it's just impractical to have a class action," said Sellers, attorney for the plaintiffs. "But there is no large-company exception to civil rights claims in this country."

Declaring class-action status for the lawsuit raises the financial and judicial stakes considerably, since more individual plaintiffs can now join, creating greater potential liability for the company being sued. In federal courts, such certification must generally follow well-established principles to ensure a lawsuit would not become so large as to be impracticable, and would allow the parties to fairly represent the common interests of the larger class of plaintiffs.

Wal-Mart also has been accused in separate lawsuits of discrimination against African-American truck drivers and workers with disabilities. In 2001 the company settled 13 lawsuits by paying out $6 million.

Most workplace discrimination lawsuits fail to reach a court for resolution, according to data compiled by the federal Equal Employment Opportunity Commission.

In 2003, when the Wal-Mart litigation was in its preliminary court stages, about 27,000 sex discrimination claims nationwide were resolved administratively by the EEOC, little changed from the prior decade. More than 57 percent -- some 15,000 claims -- were ruled administratively to have "no reasonable cause" and those usually were dismissed.

Just over 10 percent were judged to have merit, resulting in a total of $94.2 million in settlements, or $34,200 on average per case, according to the data, which include all such claims, not just those involving Wal-Mart.

The case is also a clash of dueling cultures -- some have dubbed it the Battle of Bentonville vs. Berkeley, for the corporate headquarters and the home to the liberal legal team outside San Francisco where the lawsuits first percolated.

Both sides have lots of data

Three women now sit on the high court and each brings their own personal and judicial approach to gender bias cases. This is particularly true for Justice Ruth Bader Ginsburg, a legal pioneer in promoting equality on the job.

Whether their views will sway their male colleagues is unknown, but the court in the past three decades has restricted when class actions can proceed, saying "rigorous analysis" must first be conducted by the courts. This after women, blacks, Latinos and the disabled launched high-profile class actions beginning in the 1960s.

The problem is that both Wal-Mart and the plaintiffs have presented their own massive sets of data -- statistics and depositions -- that could overwhelm any "rigorous analysis" of the facts. The dueling numbers -- which experience shows can often be manipulated in creative ways to make the point -- paint completely different pictures of the level of discrimination.

Both sides agree the case, however it is resolved in the courts, will irrevocably alter the workplace landscape for generations to come.

The case is Dukes v. Wal-Mart Stores, Inc. (10-277).

@highlight

Court to decide only whether case can proceed as class-action suit

@highlight

It would be the largest discrimination case of its kind

@highlight

Wal-Mart argues size would make case onerous