There's never been a better time to visit North Korea. The specter of U.S.-South Korean military exercises, a potential nuclear test, assassinations of defectors in South Korea, and general saber-rattling haven't prevented a record 4,000 tourists from arriving in Pyongyang this year. There's even a hopeful air among diplomats that the two Koreas, as well as China and Japan, might find the right balance of words and gestures to smooth out their emotional grievances that fuel regular nationalist flare-ups.

The scene at Beijing airport already gives clues into how North Korean society continues to defy economic gravity. Pyongyong elites check in dozens of boxes of household goods (from electronics to wine glasses) for their own use or to resell. Like upscale Iranians ferrying in and out of Dubai, the international, multilingual and urbane class may seem like precisely the ones to support regime change, but also profit the most from the status quo.

If you're willing to part with your mobile phone at Pyongyang customs (hint: you have no choice, but they'll give it back to you on departure), you'll clear the airport with an efficiency that puts New York's JFK to shame. Despite Typhoon Bolaven battering the country at the start of our visit, we came during a week when student groups, worker units, and families from all parts of the country flocked to Pyongyang for the Arirang mass games, which take place in the 150,000-capacity May Day stadium and feature up to 100,000 performers in the most spectacularly choreographed precision movements ever staged -- almost every single night.

North Koreans are no longer afraid or suspicious to engage with foreigners. Soldiers and students, bus drivers and guards, all smile and wave, snap pictures and shake hands. We encountered locals at the mass games, film studios, world's deepest underground metro, art schools, and delicious restaurants. This is not a society voluntarily marching in lockstep. Like Iranians and Cubans, they are told one story but increasingly encounter the other viewpoints through media and tourism. Our appreciation of their beautiful cultural offerings reminds them that they are a rich civilization temporarily trapped in an anachronistic state.

Outside of Pyongyang one witnesses the reality afflicting many of the country's 20 million-plus citizens: poverty and malnutrition. Most of those labeled defectors into China are actually economic migrants, and even in Pyongyang one can tell which children come from poor villages by their ragged sandals and brownish hair, made lighter by long hours under the sun in the fields.

One of Pyongyang's crown jewels is the 150-meter tall Juche tower, which celebrates the country's ideal of self-reliance. Plaques in the lobby commemorate the visits of dignitaries and earnest academics from Gambia, Tunisia, Pakistan and dozens of other nations who devoted serious study to North Korea's Juche ideology in the 1970s and 1980s. We all know what's happened to them.

North Korea too feels on the cusp of a new phase. Though it hasn't accepted Japanese apologies for World War II imperial atrocities, and its many monuments excoriate in stone America's Korean War aggression in which 420,000 bombs were dropped on Pyongyang alone (greater than the number of residents in the city at the time), the concrete high-rises with intermittent water supply and belching buses are all reaching the end of their shelf-life. Soviet support and fuel subsidies collapsed in the early 1990s, and food security has been tenuous ever since. Most investment now comes from China, but much less so ideological support. Nominally committed to the same Communist ethos, China has still become one of the world's largest economies while North Korea lacks a credit rating.

It's not likely that the young regime of Kim Jong-Un will actually collapse. Though the Arab Spring teaches us not to put much faith in the softer sons of iron-fisted rulers, North Korea is a deeply Confucian society and symbolically views itself as still run by Jong-Un's late grandfather and national revolutionary Kim Il-Sung and father Kim Jong-Il. Jong-Un is something of a caretaker while the old clique continues with anti-Japanese propaganda, nuclear brinksmanship, and threats against the South. The country's premier, Kim Jung Nam, has been increasingly visible as a decisive government official, but as with everything else in North Korea, it is a carefully staged diversification of authority, not a transition towards democracy.

As one wanders through lively street arcades full of roller-skaters and volleyball games, one has to hope that Confucian communism can make enough space for capitalism such that the burden of isolation falls on the regime rather than society. More tourism, mobile phones, and industrial joint ventures all help. One of the most promising is the Chinese funded special economic zone of Rason at the intersection of Russia and China, a warm water port that would serve all three countries. A decade from now, it could be North Korea's Shenzhen. Another is Dandong, also on China's border. Suddenly North Korea is making flat-screen televisions and its own DVD players.

While not wanting to buttress the Kim regime as China has, South Korea fears being marginalized for influence in the North and is returning to the economic engagement of its 1990s "sunshine" policy, and is considering expanding investment in its own special economic zone at Kaesong. But a rail line meant to connect Seoul and Pyongyang remains dormant. Still, the North too fears becoming too dependent on China, and like Myanmar, is courting more foreign investment for those with a high appetite for risk.

North Korea does indeed have plenty to offer. Its largely mountainous territory is rich in gold and magnesium. Mining operations are picking up, with serious interest from Australia and other extractive giants. Its mighty rivers could be key hydropower resource both to electrify the country and sell power to the South. It also produces agricultural staples like rice, corn, soybeans and potatoes. And of course there could be much more tourism, including to scenic Mt. Paekdu and to witness the centuries of well-preserved Korean traditions in Pyongyang. For example, Beijing-based Koryo Tours has increased its tourist volume from 200 to 2,000 over the past decade, almost half of which are American.

The nation's capital, the largest of its half-dozen large cities, feels like an Asian Kiev. Like Ukraine's capital, it has broad avenues with revolutionary monuments and fountains, but also a laid-back, leafy feel. Czech made trams still roll through the city ferrying workers and students between homes, offices, and schools.

North Koreans are not automatons but citizens, loyal but misinformed, curious and educated. Whether in schools, billiard halls, or karaoke bars (Some Pyongyang girls have perfected Celine Dion's "Titanic" theme song), the people can be quite open about their concerns. Some mothers would rather their kids practice the piano than spend hours training for the mass games; some teachers want their kids to focus more on math.

Outside the capital, where information flow is more a one-way street, Western powers and responsible neighbors have to provide the young Kim with opportunities to change the hostile rhetoric. After the New York Philharmonic performed in Pyongyang, the reciprocal visit was effectively killed by Washington, which rejected the North Korean visas. But how about having the mind-blowing Arirang youth performers take stage at halftime in the Superbowl? Surely Kim wouldn't call for America's destruction after that.

Indeed, Jong-Un has an opportunity now his failed Arab counterparts missed: to lead the rehabilitation of his country and enjoy his remaining decades not as a pariah but a statesman, not feared by his people but admired by them. Rather than being banned from most international travel he could enjoy basketball games in Europe as he did during high school in Switzerland.

Whether or not the North reunifies with the South like West Germany absorbing the East in the early 1990s, the current priority should be turning the country into a passageway between China and South Korea rather than a buffer. There's no guarantee that economic opening will lead to political reform; indeed, China is if anything a more likely future model of governance for North Korea than outright democratization or sudden reunification. All the more reason then to stop pretending that placing conditions on investment such as freezing the nuclear program will actually work. Diplomacy with pre-requisites has a very poor track record with nuclearizing states. Rather than wait for statues to be violently yanked down in city centers, the goal should be de facto economic integration without political humiliation. The heavily fortified De-Militarized Zone (DMZ), then, would quickly go from Cold War flashpoint to nature park given its unique ecosystem and flora.

The past 20 years of revolutions followed by slow, halting, and even reversed transitions from the Balkans to the Middle East teaches us to be guarded in our optimism about the pace of change in countries whose political and economic systems have been frozen in time. Today North Korea is like Turkmenistan, isolated and ideological. Even with a surge of infrastructure investment and technology, a decade from now it could at best become like post-Communist Romania, exporting industry and agriculture but still corrupt and destitute. But it would be an economic passageway with greater freedom and opportunity for its people, and have a greater stake in peace than war.

So come to North Korea, and come soon: the Pyongyang International Film Festival takes place in September with documentaries and avant garde movies being screened from a dozen countries.

@highlight

North Korea offers a rich experience for travelers, says Parag Khanna

@highlight

Visit the reclusive nation now as it emerges, tentatively, into the modern world

@highlight

Rich civilization temporarily trapped in an anachronistic state, he observes

@highlight

Now nation is courting more foreign investment for those with high appetite for risk