(CNN) -- Amid growing outrage over civilian casualties in Syria, there are ever more urgent calls to aid -- or at least protect -- the uprising against President Bashar al-Assad. There is renewed talk of creating safe havens and humanitarian corridors inside the country. And those demanding tougher measures are again asking why events in Syria should not prompt Libyan-style intervention by NATO and its Arab allies.

In Washington Tuesday, Sen. John McCain, R-Arizona, said the United States "should consider all options, including arming the opposition. The blood-letting has got to stop."

So far, the international community's response to the violence in Syria has been limited. There has been diplomatic censure, with envoys withdrawn or "recalled for consultations," and Syrian ambassadors expelled from several Arab states. A growing raft of sanctions is draining the Syrian regime's coffers but only gradually sapping its strength. This is not a country that has relied on international trade for its survival.

An Arab League monitoring mission is in abeyance, after a much criticized few weeks on the ground that drew ridicule even from within its own ranks and fury (for its perceived complacency) from protesters. And back in November, France floated the idea of humanitarian corridors that would be protected by armed observers -- while ruling out military intervention. So far the idea has not gained traction.

None of this amounts to the sort of pressure that will make the al-Assad regime buckle, especially when it perceives as divided both internal opposition and the international community.

Compare the situation to that in Libya -- almost a year ago. As then-Libyan leader Moammar Gadhafi was about to unleash his forces on the rebel stronghold of Benghazi, the world came together in the shape of the U.N. Security Council to authorize international intervention and prevent a bloodbath.

The French and British were prime movers behind U.N. Security Council Resolution 1973; the United States an enthusiastic supporter. Russia abstained, but at the time its ambassador noted that many questions remained "unanswered, including how it would be enforced and by whom, and what the limits of engagement would be." Russian later complained that a humanitarian mandate had become a blank check in support of the rebels.

Perhaps in part because of the bad blood over Libya, the world body has reached no similar consensus over Syria. Rather, the opposite, with some of the harshest diplomatic language traded for years. To the United States, the vetoes were a "travesty." German ambassador Peter Wittig essentially said that Moscow and Beijing had Syrian blood on their hands.

"China and Russia will now have to assume that responsibility in the face of the international public opinion and especially in the Arab world, the Arab citizens and, of course, in face of the Syrian people," Wittig said.

Beyond the rhetoric, the vetoes had a more practical consequence. NATO officials have made it clear that the alliance cannot act, by enforcing a no-fly zone for example, without U.N. support. Writer Derek Flood, recently in Syria with elements of the Free Syrian Army, says NATO officials envision no role for the alliance in Syria this year. But they have not ruled out a "coalition of the willing" outside the NATO orbit.

Both Russia and China are wary of any international action supporting protest against authoritarian rule. And Syria has been first the Soviet Union's -- and now Russia's -- key ally in the region after Egypt 'defected' in the 1970s. As it has for decades, Russia still supplies the Syrian government with weapons. One Russian analyst, Ruslan Pukhov, told CNN: "Once the Assad regime vanishes, we have zero influence in the region."

According to Andrew Tabler of the Washington Institute for Near East Policy, al-Assad has ably judged the "diplomatic red lines" to keep Moscow onside. There have been no massacres on the scale of what happened in Hama 30 years ago (when thousands were killed after a brief uprising against his father's rule) that might have forced Russia into a corner. The persistent drip of civilian casualties over almost a year has not unleashed a tide of irresistible outrage.

Last weekend's casualties in Homs, which opposition activists said numbered in the hundreds, may have changed that. But what can be done? In Bosnia, the international community declared "safe havens" for Muslims but failed to protect them. The result in July 1995 was Srebrenica, the worst massacre in Europe since 1945, when some 8,000 Bosnian Muslim civilians were killed by Serb forces. Havens are only safe when protected against superior forces.

Others support Sen. John McCain in arguing for arming the fledgling Free Syrian Army. Anne-Marie Slaughter, professor of politics and international affairs at Princeton University, told CNN that is "the most likely [option], that the Arab League countries, Turkey and probably NATO as well arms the Free Syrian Army, gives them the means to fight back.

"But then you've got a long and bloody civil war," Slaughter says -- reminiscent of Bosnia.

Analysts say that even setting aside the lack of international will, successful intervention in Syria would pose problems not present in Libya:

Geography: Most regime targets in Libya were close to the Mediterranean coast and within easy reach of NATO air bases in Italy. Even so, NATO warplanes flew some 21,000 missions over nearly six months to enforce the no-fly zone, suppress air defenses and destroy command centers and armor. Military analysts say that, while no match for the best NATO members could summon, Syrian armed forces are better equipped and coordinated than anything Gadhafi could muster.

Neighboring states: Few of Syria's neighbors would likely allow their territory to be used to pre-position supplies or military units. Certainly neither Iraq nor Lebanon, both countries with their own volatile sectarian mixes. The Hezbollah militia, strongly allied with Syria, remains powerful within Lebanon.

The presence of foreign troops on Jordanian soil might have repercussions for a monarchy that already has plenty of problems domestically. Using Israeli territory would send the wrong message altogether.

That leaves Turkey, a NATO member that has run out of patience with al-Assad. Last month, the Turkish foreign minister compared the Syrian president with former Serbian leader Slobodan Milosevic, and on Tuesday Prime Minister Recep Tayyip Erdogan warned al-Assad -- pointedly in Arabic -- "What goes around, comes around."

Turkey has military bases (Incirlik, Diyarbakir) close to the border that -- theoretically -- could serve as staging posts for intervention. But even for the Turks, there would be risks -- including a flood of refugees and possible retaliation by Damascus supporting the Kurdish terrorist group active in Turkey, the PKK.

Topography: Libya was flat desert; there was little cover for regime forces and most of the fighting was along a narrow coastal strip. "Target acquisition" was relatively simple. Syria's physical geography is more challenging; and much of its northern border with Turkey and Lebanon is mountainous, with few major roads. Getting aid into any safe havens within Syria would be a logistical nightmare.

The opposition: The Libyan rebels, for all their military shortcomings, quickly grabbed a swathe of eastern Libya and major air and seaports in Benghazi and Tobruk that became their resupply hubs. The Free Syrian Army (FSA), at best, controls a few neighborhoods in Homs and elsewhere.

'The FSA has established very small slices of liberated territory," says Derek Flood, who has just left Idlib province close to the Turkish border. He says the FSA is poorly armed; he was told the price of weapons on the black market has soared, "with a used AK-47 fetching as much as $2,000 - $3,000." Flood says the FSA in that area wants a 5 kilometer buffer zone inside Syria to provide protection from regime forces.

Crucially, the regime retains control of Syria's frontiers, and its armed forces appear cohesive, according to analysts in the region. There have been military defections, mainly of low-rank conscripts, but not of entire units with their armor.

Against all this and the political risks of western military action in yet another Muslim country, some argue there is a moral imperative -- as there was in Libya and Kosovo (done), Rwanda (ignored) and Bosnia (eventually.)

Writing last month in The Atlantic, Steven Cook argued: "If there is no intervention and political will to stop Assad's crimes remains absent, the world will once again have to answer for standing on the sidelines of a mass murder."

Cook -- a senior fellow at the Council on Foreign Relations -- asked: "At what point in the body count is international intervention deemed to be an acceptably worthwhile option that can have a positive effect on the situation? After Assad has killed 6,000 people? 7,000? 10,000? 20,000?"

Scholar Fouad Ajami agrees, telling CNN's Anderson Cooper: "Not just the Russians and Chinese, shame to the rest of us. There's abdication elsewhere, by the Turks nearby, abdication by the Arab League and Washington. Washington spent an enormous amount of time chasing after the false mirage [that] maybe we can get the Russians and Chinese on board."

Some also argue that, despite the price, there would also eventually be a strategic gain: a post-al-Assad Syria would unlikely be as close to Iran as is the current regime and might also deprive Hezbollah of critical regional support.

Others see the risks of international intervention as outweighing any benefits, with the danger that civil war would inevitably spill into Lebanon.

In an interview with CNN's Wolf Blitzer Tuesday, U.S. Ambassador to the U.N. Susan Rice preferred tighter and more coordinated sanctions, saying that "our strong preference is not to fuel what has the potential to become a full-blown civil war" by arming the opposition.

Diplomats expect a new "contact group" on Syria to involve at least the United States, France, the Arab League and Turkey.

"We think that the Assad regime is on its last legs, that the pressure is increasing, the economy is crumbling," Rice said.

Syrians may already be discounting direct intervention by the West. In one YouTube video uploaded Tuesday from Homs, a doctor pleads for help from abroad. But he directs his message to the leaders of Turkey, Qatar and Saudi Arabia.

@highlight

The United Nations' response to violence in Syria differs from its response in Libya

@highlight

Geman ambassador: Blood on hands of China, Russia

@highlight

Al-Assad has ably judged the "diplomatic red lines" to keep Moscow on its side, says Tabler